/*
 * DO NOT EDIT THIS FILE - it is generated by Glade.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <stdio.h>

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>

#include "wmccc_callbacks.h"
#include "wmccc_interface.h"
#include "wmccc_support.h"

#define GLADE_HOOKUP_OBJECT(component,widget,name) \
  g_object_set_data_full (G_OBJECT (component), name, \
    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)

#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
  g_object_set_data (G_OBJECT (component), name, widget)

GtkWidget*
create_messagebox_dialog (void)
{
  GtkWidget *messagebox_dialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *hbox5;
  GtkWidget *image2;
  GtkWidget *messagebox_label;
  GtkWidget *dialog_action_area1;
  GtkWidget *ok_button;

  messagebox_dialog = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (messagebox_dialog), _("Message from wmccc"));
  gtk_window_set_type_hint (GTK_WINDOW (messagebox_dialog), GDK_WINDOW_TYPE_HINT_DIALOG);

  dialog_vbox1 = GTK_DIALOG (messagebox_dialog)->vbox;
  gtk_widget_show (dialog_vbox1);

  hbox5 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox5);
  gtk_box_pack_start (GTK_BOX (dialog_vbox1), hbox5, TRUE, TRUE, 0);

  image2 = create_pixmap (messagebox_dialog, "badnews.xpm");
  gtk_widget_show (image2);
  gtk_box_pack_start (GTK_BOX (hbox5), image2, FALSE, FALSE, 0);

  messagebox_label = gtk_label_new (_("plop"));
  gtk_widget_show (messagebox_label);
  gtk_box_pack_start (GTK_BOX (hbox5), messagebox_label, TRUE, TRUE, 0);
  gtk_label_set_line_wrap (GTK_LABEL (messagebox_label), TRUE);
  gtk_misc_set_padding (GTK_MISC (messagebox_label), 7, 7);

  dialog_action_area1 = GTK_DIALOG (messagebox_dialog)->action_area;
  gtk_widget_show (dialog_action_area1);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area1), GTK_BUTTONBOX_END);

  ok_button = gtk_button_new_from_stock ("gtk-ok");
  gtk_widget_show (ok_button);
  gtk_dialog_add_action_widget (GTK_DIALOG (messagebox_dialog), ok_button, GTK_RESPONSE_OK);
  GTK_WIDGET_SET_FLAGS (ok_button, GTK_CAN_DEFAULT);

  g_signal_connect_swapped ((gpointer) ok_button, "clicked",
                            G_CALLBACK (gtk_widget_hide),
                            GTK_OBJECT (messagebox_dialog));

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (messagebox_dialog, messagebox_dialog, "messagebox_dialog");
  GLADE_HOOKUP_OBJECT_NO_REF (messagebox_dialog, dialog_vbox1, "dialog_vbox1");
  GLADE_HOOKUP_OBJECT (messagebox_dialog, hbox5, "hbox5");
  GLADE_HOOKUP_OBJECT (messagebox_dialog, image2, "image2");
  GLADE_HOOKUP_OBJECT (messagebox_dialog, messagebox_label, "messagebox_label");
  GLADE_HOOKUP_OBJECT_NO_REF (messagebox_dialog, dialog_action_area1, "dialog_action_area1");
  GLADE_HOOKUP_OBJECT (messagebox_dialog, ok_button, "ok_button");

  return messagebox_dialog;
}

GtkWidget*
create_new_rss_dialog (void)
{
  GtkWidget *new_rss_dialog;
  GtkWidget *dialog_vbox2;
  GtkWidget *vbox3;
  GtkWidget *hbox13;
  GtkWidget *image4;
  GtkWidget *edit_options_bt;
  GtkWidget *alignment3;
  GtkWidget *hbox14;
  GtkWidget *image3;
  GtkWidget *label39;
  GtkWidget *vbox4;
  GtkWidget *frame1;
  GtkWidget *alignment2;
  GtkWidget *hbox4;
  GtkWidget *label37;
  GtkWidget *all_names_0_;
  GtkWidget *label36;
  GtkWidget *pp_bgcolor;
  GtkWidget *label6;
  GtkWidget *frame2;
  GtkWidget *table1;
  GtkWidget *label8;
  GtkWidget *backend_url;
  GtkWidget *label9;
  GtkWidget *backend_type;
  GtkWidget *menu1;
  GtkWidget *backend_type_1;
  GtkWidget *backend_type_2;
  GtkWidget *backend_type_3;
  GtkWidget *label10;
  GtkObject *board_check_delay_adj;
  GtkWidget *board_check_delay;
  GtkWidget *checkbutton2;
  GtkWidget *label7;
  GtkWidget *dialog_action_area2;
  GtkWidget *cancel_bt;
  GtkWidget *apply_bt;
  GtkWidget *ok_bt;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  new_rss_dialog = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (new_rss_dialog), _("New RSS Feed"));
  gtk_window_set_type_hint (GTK_WINDOW (new_rss_dialog), GDK_WINDOW_TYPE_HINT_DIALOG);

  dialog_vbox2 = GTK_DIALOG (new_rss_dialog)->vbox;
  gtk_widget_show (dialog_vbox2);

  vbox3 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox3);
  gtk_box_pack_start (GTK_BOX (dialog_vbox2), vbox3, TRUE, TRUE, 0);

  hbox13 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox13);
  gtk_box_pack_start (GTK_BOX (vbox3), hbox13, FALSE, FALSE, 0);

  image4 = create_pixmap (new_rss_dialog, "logoh.png");
  gtk_widget_show (image4);
  gtk_box_pack_start (GTK_BOX (hbox13), image4, FALSE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (image4), 0, 0.5);

  edit_options_bt = gtk_button_new ();
  gtk_widget_show (edit_options_bt);
  gtk_box_pack_start (GTK_BOX (hbox13), edit_options_bt, TRUE, TRUE, 0);

  alignment3 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment3);
  gtk_container_add (GTK_CONTAINER (edit_options_bt), alignment3);

  hbox14 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox14);
  gtk_container_add (GTK_CONTAINER (alignment3), hbox14);

  image3 = gtk_image_new_from_stock ("gtk-convert", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image3);
  gtk_box_pack_start (GTK_BOX (hbox14), image3, FALSE, FALSE, 0);

  label39 = gtk_label_new_with_mnemonic (_("Click here to edit the options file"));
  gtk_widget_show (label39);
  gtk_box_pack_start (GTK_BOX (hbox14), label39, FALSE, FALSE, 0);

  vbox4 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox4);
  gtk_box_pack_start (GTK_BOX (vbox3), vbox4, TRUE, TRUE, 0);

  frame1 = gtk_frame_new (NULL);
  gtk_widget_show (frame1);
  gtk_box_pack_start (GTK_BOX (vbox4), frame1, TRUE, TRUE, 2);

  alignment2 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_show (alignment2);
  gtk_container_add (GTK_CONTAINER (frame1), alignment2);

  hbox4 = gtk_hbox_new (FALSE, 4);
  gtk_widget_show (hbox4);
  gtk_container_add (GTK_CONTAINER (alignment2), hbox4);
  gtk_container_set_border_width (GTK_CONTAINER (hbox4), 2);

  label37 = gtk_label_new (_("Give a (short) name for the RSS feed:"));
  gtk_widget_show (label37);
  gtk_box_pack_start (GTK_BOX (hbox4), label37, FALSE, FALSE, 0);

  all_names_0_ = gtk_entry_new ();
  gtk_widget_show (all_names_0_);
  gtk_box_pack_start (GTK_BOX (hbox4), all_names_0_, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, all_names_0_, _("Try to be short"), NULL);
  gtk_entry_set_text (GTK_ENTRY (all_names_0_), _("dlfp"));

  label36 = gtk_label_new (_("Background color: "));
  gtk_widget_show (label36);
  gtk_box_pack_start (GTK_BOX (hbox4), label36, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label36), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label36), 1, 0.5);

  pp_bgcolor = gtk_button_new_with_mnemonic (_("pp_bgcolor_bt"));
  gtk_widget_show (pp_bgcolor);
  gtk_box_pack_start (GTK_BOX (hbox4), pp_bgcolor, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, pp_bgcolor, _("You can customize the background color of the messages for this new site"), NULL);

  label6 = gtk_label_new (_("Basic settings"));
  gtk_widget_show (label6);
  gtk_frame_set_label_widget (GTK_FRAME (frame1), label6);

  frame2 = gtk_frame_new (NULL);
  gtk_widget_show (frame2);
  gtk_box_pack_start (GTK_BOX (vbox4), frame2, TRUE, TRUE, 2);

  table1 = gtk_table_new (4, 2, FALSE);
  gtk_widget_show (table1);
  gtk_container_add (GTK_CONTAINER (frame2), table1);
  gtk_container_set_border_width (GTK_CONTAINER (table1), 2);

  label8 = gtk_label_new (_("Backend URL:"));
  gtk_widget_show (label8);
  gtk_table_attach (GTK_TABLE (table1), label8, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8), 0, 0.5);

  backend_url = gtk_entry_new ();
  gtk_widget_show (backend_url);
  gtk_table_attach (GTK_TABLE (table1), backend_url, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_size_request (backend_url, 500, -1);
  gtk_entry_set_text (GTK_ENTRY (backend_url), _("http://linuxfr.org/board/backend.xml"));

  label9 = gtk_label_new (_("Backend flavour:"));
  gtk_widget_show (label9);
  gtk_table_attach (GTK_TABLE (table1), label9, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label9), 0, 0.5);

  backend_type = gtk_option_menu_new ();
  gtk_widget_show (backend_type);
  gtk_table_attach (GTK_TABLE (table1), backend_type, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  menu1 = gtk_menu_new ();

  backend_type_1 = gtk_menu_item_new_with_mnemonic (_("message tags are \"htmlentitised\""));
  gtk_widget_show (backend_type_1);
  gtk_container_add (GTK_CONTAINER (menu1), backend_type_1);

  backend_type_2 = gtk_menu_item_new_with_mnemonic (_("message tags are raw"));
  gtk_widget_show (backend_type_2);
  gtk_container_add (GTK_CONTAINER (menu1), backend_type_2);

  backend_type_3 = gtk_menu_item_new_with_mnemonic (_("the backend has no pants"));
  gtk_widget_show (backend_type_3);
  gtk_container_add (GTK_CONTAINER (menu1), backend_type_3);

  gtk_option_menu_set_menu (GTK_OPTION_MENU (backend_type), menu1);

  label10 = gtk_label_new (_("Refresh frequency\n (seconds): "));
  gtk_widget_show (label10);
  gtk_table_attach (GTK_TABLE (table1), label10, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label10), 0, 0.5);

  board_check_delay_adj = gtk_adjustment_new (10, 10, 10000, 1, 10, 10);
  board_check_delay = gtk_spin_button_new (GTK_ADJUSTMENT (board_check_delay_adj), 1, 0);
  gtk_widget_show (board_check_delay);
  gtk_table_attach (GTK_TABLE (table1), board_check_delay, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton2 = gtk_check_button_new_with_mnemonic (_("Ignore <description> content (some links-only feeds contain ads in this field)"));
  gtk_widget_show (checkbutton2);
  gtk_table_attach (GTK_TABLE (table1), checkbutton2, 0, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label7 = gtk_label_new (_("RSS Backend information"));
  gtk_widget_show (label7);
  gtk_frame_set_label_widget (GTK_FRAME (frame2), label7);

  dialog_action_area2 = GTK_DIALOG (new_rss_dialog)->action_area;
  gtk_widget_show (dialog_action_area2);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area2), GTK_BUTTONBOX_END);

  cancel_bt = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (cancel_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (new_rss_dialog), cancel_bt, GTK_RESPONSE_CANCEL);
  GTK_WIDGET_SET_FLAGS (cancel_bt, GTK_CAN_DEFAULT);

  apply_bt = gtk_button_new_from_stock ("gtk-apply");
  gtk_widget_show (apply_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (new_rss_dialog), apply_bt, GTK_RESPONSE_APPLY);
  GTK_WIDGET_SET_FLAGS (apply_bt, GTK_CAN_DEFAULT);

  ok_bt = gtk_button_new_from_stock ("gtk-ok");
  gtk_widget_show (ok_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (new_rss_dialog), ok_bt, GTK_RESPONSE_OK);
  GTK_WIDGET_SET_FLAGS (ok_bt, GTK_CAN_DEFAULT);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (new_rss_dialog, new_rss_dialog, "new_rss_dialog");
  GLADE_HOOKUP_OBJECT_NO_REF (new_rss_dialog, dialog_vbox2, "dialog_vbox2");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, vbox3, "vbox3");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, hbox13, "hbox13");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, image4, "image4");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, edit_options_bt, "edit_options_bt");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, alignment3, "alignment3");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, hbox14, "hbox14");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, image3, "image3");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, label39, "label39");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, vbox4, "vbox4");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, frame1, "frame1");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, alignment2, "alignment2");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, hbox4, "hbox4");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, label37, "label37");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, all_names_0_, "all_names_0_");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, label36, "label36");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, pp_bgcolor, "pp_bgcolor");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, label6, "label6");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, frame2, "frame2");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, table1, "table1");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, label8, "label8");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, backend_url, "backend_url");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, label9, "label9");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, backend_type, "backend_type");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, menu1, "menu1");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, backend_type_1, "backend_type_1");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, backend_type_2, "backend_type_2");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, backend_type_3, "backend_type_3");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, label10, "label10");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, board_check_delay, "board_check_delay");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, checkbutton2, "checkbutton2");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, label7, "label7");
  GLADE_HOOKUP_OBJECT_NO_REF (new_rss_dialog, dialog_action_area2, "dialog_action_area2");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, cancel_bt, "cancel_bt");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, apply_bt, "apply_bt");
  GLADE_HOOKUP_OBJECT (new_rss_dialog, ok_bt, "ok_bt");
  GLADE_HOOKUP_OBJECT_NO_REF (new_rss_dialog, tooltips, "tooltips");

  return new_rss_dialog;
}

GtkWidget*
create_new_board_dialog (void)
{
  GtkWidget *new_board_dialog;
  GtkWidget *dialog_vbox2;
  GtkWidget *vbox3;
  GtkWidget *hbox13;
  GtkWidget *image4;
  GtkWidget *edit_options_bt;
  GtkWidget *alignment3;
  GtkWidget *hbox14;
  GtkWidget *image3;
  GtkWidget *label39;
  GtkWidget *vbox4;
  GtkWidget *frame1;
  GtkWidget *alignment2;
  GtkWidget *hbox4;
  GtkWidget *label37;
  GtkWidget *all_names_0_;
  GtkWidget *label36;
  GtkWidget *pp_bgcolor;
  GtkWidget *label6;
  GtkWidget *frame2;
  GtkWidget *table1;
  GtkWidget *label8;
  GtkWidget *backend_url;
  GtkWidget *label9;
  GtkWidget *backend_type;
  GtkWidget *menu1;
  GtkWidget *backend_type_1;
  GtkWidget *backend_type_2;
  GtkWidget *backend_type_3;
  GtkWidget *label10;
  GtkObject *board_check_delay_adj;
  GtkWidget *board_check_delay;
  GtkWidget *label7;
  GtkWidget *frame3;
  GtkWidget *alignment1;
  GtkWidget *table2;
  GtkWidget *label12;
  GtkWidget *post_url;
  GtkWidget *label13;
  GtkWidget *post_template;
  GtkWidget *scrolledwindow2;
  GtkWidget *viewport1;
  GtkWidget *user_cookie;
  GtkWidget *grab_cookie_bt;
  GtkWidget *alignment9;
  GtkWidget *hbox29;
  GtkWidget *image12;
  GtkWidget *label78;
  GtkWidget *label14;
  GtkWidget *hunt_opened_on_site;
  GtkWidget *label11;
  GtkWidget *dialog_action_area2;
  GtkWidget *cancel_bt;
  GtkWidget *apply_bt;
  GtkWidget *ok_bt;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  new_board_dialog = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (new_board_dialog), _("New Board"));
  gtk_window_set_type_hint (GTK_WINDOW (new_board_dialog), GDK_WINDOW_TYPE_HINT_DIALOG);

  dialog_vbox2 = GTK_DIALOG (new_board_dialog)->vbox;
  gtk_widget_show (dialog_vbox2);

  vbox3 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox3);
  gtk_box_pack_start (GTK_BOX (dialog_vbox2), vbox3, TRUE, TRUE, 0);

  hbox13 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox13);
  gtk_box_pack_start (GTK_BOX (vbox3), hbox13, FALSE, FALSE, 0);

  image4 = create_pixmap (new_board_dialog, "logoh.png");
  gtk_widget_show (image4);
  gtk_box_pack_start (GTK_BOX (hbox13), image4, FALSE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (image4), 0, 0.5);

  edit_options_bt = gtk_button_new ();
  gtk_widget_show (edit_options_bt);
  gtk_box_pack_start (GTK_BOX (hbox13), edit_options_bt, TRUE, TRUE, 0);

  alignment3 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment3);
  gtk_container_add (GTK_CONTAINER (edit_options_bt), alignment3);

  hbox14 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox14);
  gtk_container_add (GTK_CONTAINER (alignment3), hbox14);

  image3 = gtk_image_new_from_stock ("gtk-convert", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image3);
  gtk_box_pack_start (GTK_BOX (hbox14), image3, FALSE, FALSE, 0);

  label39 = gtk_label_new_with_mnemonic (_("Click here to edit the options file"));
  gtk_widget_show (label39);
  gtk_box_pack_start (GTK_BOX (hbox14), label39, FALSE, FALSE, 0);

  vbox4 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox4);
  gtk_box_pack_start (GTK_BOX (vbox3), vbox4, TRUE, TRUE, 0);

  frame1 = gtk_frame_new (NULL);
  gtk_widget_show (frame1);
  gtk_box_pack_start (GTK_BOX (vbox4), frame1, TRUE, TRUE, 2);

  alignment2 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_show (alignment2);
  gtk_container_add (GTK_CONTAINER (frame1), alignment2);

  hbox4 = gtk_hbox_new (FALSE, 4);
  gtk_widget_show (hbox4);
  gtk_container_add (GTK_CONTAINER (alignment2), hbox4);
  gtk_container_set_border_width (GTK_CONTAINER (hbox4), 2);

  label37 = gtk_label_new (_("Give a (short) name for the board:"));
  gtk_widget_show (label37);
  gtk_box_pack_start (GTK_BOX (hbox4), label37, FALSE, FALSE, 0);

  all_names_0_ = gtk_entry_new ();
  gtk_widget_show (all_names_0_);
  gtk_box_pack_start (GTK_BOX (hbox4), all_names_0_, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, all_names_0_, _("Try to be short"), NULL);
  gtk_entry_set_text (GTK_ENTRY (all_names_0_), _("dlfp"));

  label36 = gtk_label_new (_("Background color: "));
  gtk_widget_show (label36);
  gtk_box_pack_start (GTK_BOX (hbox4), label36, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label36), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label36), 1, 0.5);

  pp_bgcolor = gtk_button_new_with_mnemonic (_("pp_bgcolor_bt"));
  gtk_widget_show (pp_bgcolor);
  gtk_box_pack_start (GTK_BOX (hbox4), pp_bgcolor, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, pp_bgcolor, _("You can customize the background color of the messages for this new site"), NULL);

  label6 = gtk_label_new (_("Basic settings"));
  gtk_widget_show (label6);
  gtk_frame_set_label_widget (GTK_FRAME (frame1), label6);

  frame2 = gtk_frame_new (NULL);
  gtk_widget_show (frame2);
  gtk_box_pack_start (GTK_BOX (vbox4), frame2, TRUE, TRUE, 2);

  table1 = gtk_table_new (3, 2, FALSE);
  gtk_widget_show (table1);
  gtk_container_add (GTK_CONTAINER (frame2), table1);
  gtk_container_set_border_width (GTK_CONTAINER (table1), 2);

  label8 = gtk_label_new (_("Backend URL:"));
  gtk_widget_show (label8);
  gtk_table_attach (GTK_TABLE (table1), label8, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8), 0, 0.5);

  backend_url = gtk_entry_new ();
  gtk_widget_show (backend_url);
  gtk_table_attach (GTK_TABLE (table1), backend_url, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_size_request (backend_url, 500, -1);
  gtk_entry_set_text (GTK_ENTRY (backend_url), _("http://linuxfr.org/board/backend.xml"));

  label9 = gtk_label_new (_("Backend flavour:"));
  gtk_widget_show (label9);
  gtk_table_attach (GTK_TABLE (table1), label9, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label9), 0, 0.5);

  backend_type = gtk_option_menu_new ();
  gtk_widget_show (backend_type);
  gtk_table_attach (GTK_TABLE (table1), backend_type, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  menu1 = gtk_menu_new ();

  backend_type_1 = gtk_menu_item_new_with_mnemonic (_("message tags are \"htmlentitised\""));
  gtk_widget_show (backend_type_1);
  gtk_container_add (GTK_CONTAINER (menu1), backend_type_1);

  backend_type_2 = gtk_menu_item_new_with_mnemonic (_("message tags are raw"));
  gtk_widget_show (backend_type_2);
  gtk_container_add (GTK_CONTAINER (menu1), backend_type_2);

  backend_type_3 = gtk_menu_item_new_with_mnemonic (_("the backend has no pants"));
  gtk_widget_show (backend_type_3);
  gtk_container_add (GTK_CONTAINER (menu1), backend_type_3);

  gtk_option_menu_set_menu (GTK_OPTION_MENU (backend_type), menu1);

  label10 = gtk_label_new (_("Refresh frequency\n (seconds): "));
  gtk_widget_show (label10);
  gtk_table_attach (GTK_TABLE (table1), label10, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label10), 0, 0.5);

  board_check_delay_adj = gtk_adjustment_new (10, 10, 10000, 1, 10, 10);
  board_check_delay = gtk_spin_button_new (GTK_ADJUSTMENT (board_check_delay_adj), 1, 0);
  gtk_widget_show (board_check_delay);
  gtk_table_attach (GTK_TABLE (table1), board_check_delay, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label7 = gtk_label_new (_("XML Backend information"));
  gtk_widget_show (label7);
  gtk_frame_set_label_widget (GTK_FRAME (frame2), label7);

  frame3 = gtk_frame_new (NULL);
  gtk_widget_show (frame3);
  gtk_box_pack_start (GTK_BOX (vbox4), frame3, TRUE, TRUE, 2);

  alignment1 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_show (alignment1);
  gtk_container_add (GTK_CONTAINER (frame3), alignment1);

  table2 = gtk_table_new (4, 3, FALSE);
  gtk_widget_show (table2);
  gtk_container_add (GTK_CONTAINER (alignment1), table2);
  gtk_container_set_border_width (GTK_CONTAINER (table2), 2);

  label12 = gtk_label_new (_("Post URL:"));
  gtk_widget_show (label12);
  gtk_table_attach (GTK_TABLE (table2), label12, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label12), 0, 0.5);

  post_url = gtk_entry_new ();
  gtk_widget_show (post_url);
  gtk_table_attach (GTK_TABLE (table2), post_url, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label13 = gtk_label_new (_("Post Template:"));
  gtk_widget_show (label13);
  gtk_table_attach (GTK_TABLE (table2), label13, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label13), 0, 0.5);

  post_template = gtk_entry_new ();
  gtk_widget_show (post_template);
  gtk_table_attach (GTK_TABLE (table2), post_template, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  scrolledwindow2 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow2);
  gtk_table_attach (GTK_TABLE (table2), scrolledwindow2, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow2), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);

  viewport1 = gtk_viewport_new (NULL, NULL);
  gtk_widget_show (viewport1);
  gtk_container_add (GTK_CONTAINER (scrolledwindow2), viewport1);

  user_cookie = gtk_entry_new ();
  gtk_widget_show (user_cookie);
  gtk_container_add (GTK_CONTAINER (viewport1), user_cookie);

  grab_cookie_bt = gtk_button_new ();
  gtk_widget_show (grab_cookie_bt);
  gtk_table_attach (GTK_TABLE (table2), grab_cookie_bt, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, grab_cookie_bt, _("attempt to get the cookie from the cookies stored in your browsers"), NULL);

  alignment9 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment9);
  gtk_container_add (GTK_CONTAINER (grab_cookie_bt), alignment9);

  hbox29 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox29);
  gtk_container_add (GTK_CONTAINER (alignment9), hbox29);

  image12 = gtk_image_new_from_stock ("gtk-find", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image12);
  gtk_box_pack_start (GTK_BOX (hbox29), image12, FALSE, FALSE, 0);

  label78 = gtk_label_new_with_mnemonic (_("(grab cookie)"));
  gtk_widget_show (label78);
  gtk_box_pack_start (GTK_BOX (hbox29), label78, FALSE, FALSE, 0);

  label14 = gtk_label_new (_("Cookie(s)"));
  gtk_widget_show (label14);
  gtk_table_attach (GTK_TABLE (table2), label14, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label14), 0, 0.5);

  hunt_opened_on_site = gtk_check_button_new_with_mnemonic (_("balltrap is allowed on this board"));
  gtk_widget_show (hunt_opened_on_site);
  gtk_table_attach (GTK_TABLE (table2), hunt_opened_on_site, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, hunt_opened_on_site, _("you can enable/disable the balltrap for each site. Note that there is also a global switch for the balltrap in the pinnipede button bar."), NULL);

  label11 = gtk_label_new (_("Sending messages to the board"));
  gtk_widget_show (label11);
  gtk_frame_set_label_widget (GTK_FRAME (frame3), label11);

  dialog_action_area2 = GTK_DIALOG (new_board_dialog)->action_area;
  gtk_widget_show (dialog_action_area2);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area2), GTK_BUTTONBOX_END);

  cancel_bt = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (cancel_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (new_board_dialog), cancel_bt, GTK_RESPONSE_CANCEL);
  GTK_WIDGET_SET_FLAGS (cancel_bt, GTK_CAN_DEFAULT);

  apply_bt = gtk_button_new_from_stock ("gtk-apply");
  gtk_widget_show (apply_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (new_board_dialog), apply_bt, GTK_RESPONSE_APPLY);
  GTK_WIDGET_SET_FLAGS (apply_bt, GTK_CAN_DEFAULT);

  ok_bt = gtk_button_new_from_stock ("gtk-ok");
  gtk_widget_show (ok_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (new_board_dialog), ok_bt, GTK_RESPONSE_OK);
  GTK_WIDGET_SET_FLAGS (ok_bt, GTK_CAN_DEFAULT);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (new_board_dialog, new_board_dialog, "new_board_dialog");
  GLADE_HOOKUP_OBJECT_NO_REF (new_board_dialog, dialog_vbox2, "dialog_vbox2");
  GLADE_HOOKUP_OBJECT (new_board_dialog, vbox3, "vbox3");
  GLADE_HOOKUP_OBJECT (new_board_dialog, hbox13, "hbox13");
  GLADE_HOOKUP_OBJECT (new_board_dialog, image4, "image4");
  GLADE_HOOKUP_OBJECT (new_board_dialog, edit_options_bt, "edit_options_bt");
  GLADE_HOOKUP_OBJECT (new_board_dialog, alignment3, "alignment3");
  GLADE_HOOKUP_OBJECT (new_board_dialog, hbox14, "hbox14");
  GLADE_HOOKUP_OBJECT (new_board_dialog, image3, "image3");
  GLADE_HOOKUP_OBJECT (new_board_dialog, label39, "label39");
  GLADE_HOOKUP_OBJECT (new_board_dialog, vbox4, "vbox4");
  GLADE_HOOKUP_OBJECT (new_board_dialog, frame1, "frame1");
  GLADE_HOOKUP_OBJECT (new_board_dialog, alignment2, "alignment2");
  GLADE_HOOKUP_OBJECT (new_board_dialog, hbox4, "hbox4");
  GLADE_HOOKUP_OBJECT (new_board_dialog, label37, "label37");
  GLADE_HOOKUP_OBJECT (new_board_dialog, all_names_0_, "all_names_0_");
  GLADE_HOOKUP_OBJECT (new_board_dialog, label36, "label36");
  GLADE_HOOKUP_OBJECT (new_board_dialog, pp_bgcolor, "pp_bgcolor");
  GLADE_HOOKUP_OBJECT (new_board_dialog, label6, "label6");
  GLADE_HOOKUP_OBJECT (new_board_dialog, frame2, "frame2");
  GLADE_HOOKUP_OBJECT (new_board_dialog, table1, "table1");
  GLADE_HOOKUP_OBJECT (new_board_dialog, label8, "label8");
  GLADE_HOOKUP_OBJECT (new_board_dialog, backend_url, "backend_url");
  GLADE_HOOKUP_OBJECT (new_board_dialog, label9, "label9");
  GLADE_HOOKUP_OBJECT (new_board_dialog, backend_type, "backend_type");
  GLADE_HOOKUP_OBJECT (new_board_dialog, menu1, "menu1");
  GLADE_HOOKUP_OBJECT (new_board_dialog, backend_type_1, "backend_type_1");
  GLADE_HOOKUP_OBJECT (new_board_dialog, backend_type_2, "backend_type_2");
  GLADE_HOOKUP_OBJECT (new_board_dialog, backend_type_3, "backend_type_3");
  GLADE_HOOKUP_OBJECT (new_board_dialog, label10, "label10");
  GLADE_HOOKUP_OBJECT (new_board_dialog, board_check_delay, "board_check_delay");
  GLADE_HOOKUP_OBJECT (new_board_dialog, label7, "label7");
  GLADE_HOOKUP_OBJECT (new_board_dialog, frame3, "frame3");
  GLADE_HOOKUP_OBJECT (new_board_dialog, alignment1, "alignment1");
  GLADE_HOOKUP_OBJECT (new_board_dialog, table2, "table2");
  GLADE_HOOKUP_OBJECT (new_board_dialog, label12, "label12");
  GLADE_HOOKUP_OBJECT (new_board_dialog, post_url, "post_url");
  GLADE_HOOKUP_OBJECT (new_board_dialog, label13, "label13");
  GLADE_HOOKUP_OBJECT (new_board_dialog, post_template, "post_template");
  GLADE_HOOKUP_OBJECT (new_board_dialog, scrolledwindow2, "scrolledwindow2");
  GLADE_HOOKUP_OBJECT (new_board_dialog, viewport1, "viewport1");
  GLADE_HOOKUP_OBJECT (new_board_dialog, user_cookie, "user_cookie");
  GLADE_HOOKUP_OBJECT (new_board_dialog, grab_cookie_bt, "grab_cookie_bt");
  GLADE_HOOKUP_OBJECT (new_board_dialog, alignment9, "alignment9");
  GLADE_HOOKUP_OBJECT (new_board_dialog, hbox29, "hbox29");
  GLADE_HOOKUP_OBJECT (new_board_dialog, image12, "image12");
  GLADE_HOOKUP_OBJECT (new_board_dialog, label78, "label78");
  GLADE_HOOKUP_OBJECT (new_board_dialog, label14, "label14");
  GLADE_HOOKUP_OBJECT (new_board_dialog, hunt_opened_on_site, "hunt_opened_on_site");
  GLADE_HOOKUP_OBJECT (new_board_dialog, label11, "label11");
  GLADE_HOOKUP_OBJECT_NO_REF (new_board_dialog, dialog_action_area2, "dialog_action_area2");
  GLADE_HOOKUP_OBJECT (new_board_dialog, cancel_bt, "cancel_bt");
  GLADE_HOOKUP_OBJECT (new_board_dialog, apply_bt, "apply_bt");
  GLADE_HOOKUP_OBJECT (new_board_dialog, ok_bt, "ok_bt");
  GLADE_HOOKUP_OBJECT_NO_REF (new_board_dialog, tooltips, "tooltips");

  return new_board_dialog;
}

GtkWidget*
create_new_pop_dialog (void)
{
  GtkWidget *new_pop_dialog;
  GtkWidget *dialog_vbox2;
  GtkWidget *vbox3;
  GtkWidget *hbox13;
  GtkWidget *image4;
  GtkWidget *edit_options_bt;
  GtkWidget *alignment3;
  GtkWidget *hbox14;
  GtkWidget *image3;
  GtkWidget *label39;
  GtkWidget *vbox4;
  GtkWidget *frame1;
  GtkWidget *alignment2;
  GtkWidget *hbox4;
  GtkWidget *label37;
  GtkWidget *all_names_0_;
  GtkWidget *label36;
  GtkWidget *pp_bgcolor;
  GtkWidget *label6;
  GtkWidget *frame2;
  GtkWidget *table1;
  GtkWidget *label8;
  GtkWidget *backend_url;
  GtkWidget *label10;
  GtkObject *board_check_delay_adj;
  GtkWidget *board_check_delay;
  GtkWidget *label62;
  GtkWidget *pop3_user;
  GtkWidget *label63;
  GtkWidget *pop3_pass;
  GtkWidget *label7;
  GtkWidget *dialog_action_area2;
  GtkWidget *cancel_bt;
  GtkWidget *apply_bt;
  GtkWidget *ok_bt;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  new_pop_dialog = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (new_pop_dialog), _("New POP"));
  gtk_window_set_type_hint (GTK_WINDOW (new_pop_dialog), GDK_WINDOW_TYPE_HINT_DIALOG);

  dialog_vbox2 = GTK_DIALOG (new_pop_dialog)->vbox;
  gtk_widget_show (dialog_vbox2);

  vbox3 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox3);
  gtk_box_pack_start (GTK_BOX (dialog_vbox2), vbox3, TRUE, TRUE, 0);

  hbox13 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox13);
  gtk_box_pack_start (GTK_BOX (vbox3), hbox13, FALSE, FALSE, 0);

  image4 = create_pixmap (new_pop_dialog, "logoh.png");
  gtk_widget_show (image4);
  gtk_box_pack_start (GTK_BOX (hbox13), image4, FALSE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (image4), 0, 0.5);

  edit_options_bt = gtk_button_new ();
  gtk_widget_show (edit_options_bt);
  gtk_box_pack_start (GTK_BOX (hbox13), edit_options_bt, TRUE, TRUE, 0);

  alignment3 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment3);
  gtk_container_add (GTK_CONTAINER (edit_options_bt), alignment3);

  hbox14 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox14);
  gtk_container_add (GTK_CONTAINER (alignment3), hbox14);

  image3 = gtk_image_new_from_stock ("gtk-convert", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image3);
  gtk_box_pack_start (GTK_BOX (hbox14), image3, FALSE, FALSE, 0);

  label39 = gtk_label_new_with_mnemonic (_("Click here to edit the options file"));
  gtk_widget_show (label39);
  gtk_box_pack_start (GTK_BOX (hbox14), label39, FALSE, FALSE, 0);

  vbox4 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox4);
  gtk_box_pack_start (GTK_BOX (vbox3), vbox4, TRUE, TRUE, 0);

  frame1 = gtk_frame_new (NULL);
  gtk_widget_show (frame1);
  gtk_box_pack_start (GTK_BOX (vbox4), frame1, TRUE, TRUE, 2);

  alignment2 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_show (alignment2);
  gtk_container_add (GTK_CONTAINER (frame1), alignment2);

  hbox4 = gtk_hbox_new (FALSE, 4);
  gtk_widget_show (hbox4);
  gtk_container_add (GTK_CONTAINER (alignment2), hbox4);
  gtk_container_set_border_width (GTK_CONTAINER (hbox4), 2);

  label37 = gtk_label_new (_("Give a (short) name for the board:"));
  gtk_widget_show (label37);
  gtk_box_pack_start (GTK_BOX (hbox4), label37, FALSE, FALSE, 0);

  all_names_0_ = gtk_entry_new ();
  gtk_widget_show (all_names_0_);
  gtk_box_pack_start (GTK_BOX (hbox4), all_names_0_, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, all_names_0_, _("Try to be short"), NULL);
  gtk_entry_set_text (GTK_ENTRY (all_names_0_), _("altern"));

  label36 = gtk_label_new (_("Background color: "));
  gtk_widget_show (label36);
  gtk_box_pack_start (GTK_BOX (hbox4), label36, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label36), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label36), 1, 0.5);

  pp_bgcolor = gtk_button_new_with_mnemonic (_("pp_bgcolor_bt"));
  gtk_widget_show (pp_bgcolor);
  gtk_box_pack_start (GTK_BOX (hbox4), pp_bgcolor, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, pp_bgcolor, _("You can customize the background color of the messages for this new site"), NULL);

  label6 = gtk_label_new (_("Basic settings"));
  gtk_widget_show (label6);
  gtk_frame_set_label_widget (GTK_FRAME (frame1), label6);

  frame2 = gtk_frame_new (NULL);
  gtk_widget_show (frame2);
  gtk_box_pack_start (GTK_BOX (vbox4), frame2, TRUE, TRUE, 2);

  table1 = gtk_table_new (4, 2, FALSE);
  gtk_widget_show (table1);
  gtk_container_add (GTK_CONTAINER (frame2), table1);
  gtk_container_set_border_width (GTK_CONTAINER (table1), 2);

  label8 = gtk_label_new (_("POP3 URL:"));
  gtk_widget_show (label8);
  gtk_table_attach (GTK_TABLE (table1), label8, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8), 0, 0.5);

  backend_url = gtk_entry_new ();
  gtk_widget_show (backend_url);
  gtk_table_attach (GTK_TABLE (table1), backend_url, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_size_request (backend_url, 500, -1);
  gtk_entry_set_text (GTK_ENTRY (backend_url), _("pop3://"));

  label10 = gtk_label_new (_("Refresh frequency\n (seconds): "));
  gtk_widget_show (label10);
  gtk_table_attach (GTK_TABLE (table1), label10, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label10), 0, 0.5);

  board_check_delay_adj = gtk_adjustment_new (300, 10, 10000, 1, 10, 10);
  board_check_delay = gtk_spin_button_new (GTK_ADJUSTMENT (board_check_delay_adj), 1, 0);
  gtk_widget_show (board_check_delay);
  gtk_table_attach (GTK_TABLE (table1), board_check_delay, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label62 = gtk_label_new (_("Login"));
  gtk_widget_show (label62);
  gtk_table_attach (GTK_TABLE (table1), label62, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label62), 0, 0.5);

  pop3_user = gtk_entry_new ();
  gtk_widget_show (pop3_user);
  gtk_table_attach (GTK_TABLE (table1), pop3_user, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label63 = gtk_label_new (_("Password"));
  gtk_widget_show (label63);
  gtk_table_attach (GTK_TABLE (table1), label63, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label63), 0, 0.5);

  pop3_pass = gtk_entry_new ();
  gtk_widget_show (pop3_pass);
  gtk_table_attach (GTK_TABLE (table1), pop3_pass, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_visibility (GTK_ENTRY (pop3_pass), FALSE);

  label7 = gtk_label_new (_("Mail account information"));
  gtk_widget_show (label7);
  gtk_frame_set_label_widget (GTK_FRAME (frame2), label7);

  dialog_action_area2 = GTK_DIALOG (new_pop_dialog)->action_area;
  gtk_widget_show (dialog_action_area2);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area2), GTK_BUTTONBOX_END);

  cancel_bt = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (cancel_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (new_pop_dialog), cancel_bt, GTK_RESPONSE_CANCEL);
  GTK_WIDGET_SET_FLAGS (cancel_bt, GTK_CAN_DEFAULT);

  apply_bt = gtk_button_new_from_stock ("gtk-apply");
  gtk_widget_show (apply_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (new_pop_dialog), apply_bt, GTK_RESPONSE_APPLY);
  GTK_WIDGET_SET_FLAGS (apply_bt, GTK_CAN_DEFAULT);

  ok_bt = gtk_button_new_from_stock ("gtk-ok");
  gtk_widget_show (ok_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (new_pop_dialog), ok_bt, GTK_RESPONSE_OK);
  GTK_WIDGET_SET_FLAGS (ok_bt, GTK_CAN_DEFAULT);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (new_pop_dialog, new_pop_dialog, "new_pop_dialog");
  GLADE_HOOKUP_OBJECT_NO_REF (new_pop_dialog, dialog_vbox2, "dialog_vbox2");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, vbox3, "vbox3");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, hbox13, "hbox13");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, image4, "image4");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, edit_options_bt, "edit_options_bt");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, alignment3, "alignment3");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, hbox14, "hbox14");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, image3, "image3");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, label39, "label39");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, vbox4, "vbox4");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, frame1, "frame1");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, alignment2, "alignment2");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, hbox4, "hbox4");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, label37, "label37");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, all_names_0_, "all_names_0_");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, label36, "label36");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, pp_bgcolor, "pp_bgcolor");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, label6, "label6");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, frame2, "frame2");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, table1, "table1");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, label8, "label8");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, backend_url, "backend_url");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, label10, "label10");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, board_check_delay, "board_check_delay");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, label62, "label62");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, pop3_user, "pop3_user");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, label63, "label63");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, pop3_pass, "pop3_pass");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, label7, "label7");
  GLADE_HOOKUP_OBJECT_NO_REF (new_pop_dialog, dialog_action_area2, "dialog_action_area2");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, cancel_bt, "cancel_bt");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, apply_bt, "apply_bt");
  GLADE_HOOKUP_OBJECT (new_pop_dialog, ok_bt, "ok_bt");
  GLADE_HOOKUP_OBJECT_NO_REF (new_pop_dialog, tooltips, "tooltips");

  return new_pop_dialog;
}

GtkWidget*
create_colorselection_dialog (void)
{
  GtkWidget *colorselection_dialog;
  GtkWidget *ok_button1;
  GtkWidget *cancel_button1;
  GtkWidget *help_button1;
  GtkWidget *color_selection1;

  colorselection_dialog = gtk_color_selection_dialog_new (_("Choix de la couleur"));
  gtk_window_set_resizable (GTK_WINDOW (colorselection_dialog), FALSE);
  gtk_window_set_type_hint (GTK_WINDOW (colorselection_dialog), GDK_WINDOW_TYPE_HINT_DIALOG);

  ok_button1 = GTK_COLOR_SELECTION_DIALOG (colorselection_dialog)->ok_button;
  gtk_widget_show (ok_button1);
  GTK_WIDGET_SET_FLAGS (ok_button1, GTK_CAN_DEFAULT);

  cancel_button1 = GTK_COLOR_SELECTION_DIALOG (colorselection_dialog)->cancel_button;
  gtk_widget_show (cancel_button1);
  GTK_WIDGET_SET_FLAGS (cancel_button1, GTK_CAN_DEFAULT);

  help_button1 = GTK_COLOR_SELECTION_DIALOG (colorselection_dialog)->help_button;
  gtk_widget_show (help_button1);
  GTK_WIDGET_SET_FLAGS (help_button1, GTK_CAN_DEFAULT);

  color_selection1 = GTK_COLOR_SELECTION_DIALOG (colorselection_dialog)->colorsel;
  gtk_widget_show (color_selection1);
  gtk_color_selection_set_has_opacity_control (GTK_COLOR_SELECTION (color_selection1), FALSE);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (colorselection_dialog, colorselection_dialog, "colorselection_dialog");
  GLADE_HOOKUP_OBJECT_NO_REF (colorselection_dialog, ok_button1, "ok_button1");
  GLADE_HOOKUP_OBJECT_NO_REF (colorselection_dialog, cancel_button1, "cancel_button1");
  GLADE_HOOKUP_OBJECT_NO_REF (colorselection_dialog, help_button1, "help_button1");
  GLADE_HOOKUP_OBJECT_NO_REF (colorselection_dialog, color_selection1, "color_selection1");

  return colorselection_dialog;
}

GtkWidget*
create_global_pinnipede_options_dialog (void)
{
  GtkWidget *global_pinnipede_options_dialog;
  GtkWidget *dialog_vbox3;
  GtkWidget *notebook1;
  GtkWidget *vbox5;
  GtkWidget *label15;
  GtkWidget *frame4;
  GtkWidget *vbox6;
  GtkWidget *hbox9;
  GtkWidget *pinnipede_open_on_start;
  GtkWidget *pinnipede_open_on_start_fb;
  GtkWidget *frame6;
  GtkWidget *vbox24;
  GtkWidget *hbox6;
  GtkWidget *label19;
  GtkWidget *combo1;
  GList *combo1_items = NULL;
  GtkWidget *pp_fn_family;
  GtkWidget *label20;
  GtkObject *pp_fn_size_adj;
  GtkWidget *pp_fn_size;
  GtkWidget *font_bt;
  GtkWidget *hbox18;
  GtkWidget *disable_xft_antialiasing;
  GtkWidget *disable_xft_antialiasing_fb;
  GtkWidget *label18;
  GtkWidget *frame12;
  GtkWidget *hbox42;
  GtkWidget *hbox43;
  GtkWidget *label107;
  GtkWidget *pp_tabs_pos;
  GtkWidget *menu3;
  GtkWidget *bottom1;
  GtkWidget *left1;
  GtkWidget *right1;
  GtkWidget *vbox26;
  GtkWidget *hbox10;
  GtkWidget *pp_use_classical_tabs;
  GtkWidget *pp_use_classical_tabs_fb;
  GtkWidget *hbox11;
  GtkWidget *pp_use_colored_tabs;
  GtkWidget *pp_use_colored_tabs_fb;
  GtkWidget *label106;
  GtkWidget *hbox12;
  GtkWidget *hungry_boitakon;
  GtkWidget *hungry_boitakon_fb;
  GtkWidget *hbox23;
  GtkWidget *auto_swallow;
  GtkWidget *auto_swallow_fb;
  GtkWidget *hbox32;
  GtkWidget *enable_troll_detector;
  GtkWidget *enable_troll_detector_fb;
  GtkWidget *hbox2;
  GtkWidget *pp_show_sec_mode;
  GtkWidget *pp_show_sec_mode_fb;
  GtkWidget *label16;
  GtkWidget *hbox36;
  GtkWidget *image15;
  GtkWidget *label95;
  GtkWidget *label87;
  GtkWidget *vbox17;
  GtkWidget *table6;
  GtkWidget *label81;
  GtkWidget *label82;
  GtkWidget *combo2;
  GList *combo2_items = NULL;
  GtkWidget *browser_cmd;
  GtkWidget *combo3;
  GList *combo3_items = NULL;
  GtkWidget *browser2_cmd;
  GtkWidget *browser_cmd_fb;
  GtkWidget *browser2_cmd_fb;
  GtkWidget *label85;
  GtkWidget *label88;
  GtkWidget *vbox19;
  GtkWidget *hbox33;
  GtkWidget *image14;
  GtkWidget *vbox20;
  GtkWidget *hbox34;
  GtkWidget *board_enable_hfr_pictures;
  GtkWidget *board_enable_hfr_pictures_fb;
  GtkWidget *hbox35;
  GtkWidget *board_auto_dl_pictures;
  GtkWidget *board_auto_dl_pictures_fb;
  GtkWidget *hseparator7;
  GtkWidget *hbox7;
  GtkWidget *label21;
  GtkWidget *combo4;
  GList *combo4_items = NULL;
  GtkWidget *board_totoz_server;
  GtkWidget *label94;
  GtkWidget *label92;
  GtkWidget *vbox18;
  GtkWidget *hunt_opened;
  GtkWidget *hbox31;
  GtkWidget *label90;
  GtkObject *hunt_max_duck_adj;
  GtkWidget *hunt_max_duck;
  GtkWidget *hseparator6;
  GtkWidget *label91;
  GtkWidget *label89;
  GtkWidget *dialog_action_area3;
  GtkWidget *cancel_bt;
  GtkWidget *apply_bt;
  GtkWidget *ok_bt;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  global_pinnipede_options_dialog = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (global_pinnipede_options_dialog), _("Change pinnipede settings"));
  gtk_window_set_type_hint (GTK_WINDOW (global_pinnipede_options_dialog), GDK_WINDOW_TYPE_HINT_DIALOG);

  dialog_vbox3 = GTK_DIALOG (global_pinnipede_options_dialog)->vbox;
  gtk_widget_show (dialog_vbox3);

  notebook1 = gtk_notebook_new ();
  gtk_widget_show (notebook1);
  gtk_box_pack_start (GTK_BOX (dialog_vbox3), notebook1, TRUE, TRUE, 0);

  vbox5 = gtk_vbox_new (FALSE, 2);
  gtk_widget_show (vbox5);
  gtk_container_add (GTK_CONTAINER (notebook1), vbox5);

  label15 = gtk_label_new (_("Change pinnipede options"));
  gtk_widget_show (label15);
  gtk_box_pack_start (GTK_BOX (vbox5), label15, FALSE, FALSE, 0);

  frame4 = gtk_frame_new (NULL);
  gtk_widget_show (frame4);
  gtk_box_pack_start (GTK_BOX (vbox5), frame4, TRUE, TRUE, 0);

  vbox6 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox6);
  gtk_container_add (GTK_CONTAINER (frame4), vbox6);

  hbox9 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox9);
  gtk_box_pack_start (GTK_BOX (vbox6), hbox9, TRUE, TRUE, 0);

  pinnipede_open_on_start = gtk_check_button_new_with_mnemonic (_("Auto-open on startup "));
  gtk_widget_show (pinnipede_open_on_start);
  gtk_box_pack_start (GTK_BOX (hbox9), pinnipede_open_on_start, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, pinnipede_open_on_start, _("The pinnipede window will show up as soon as wmcoincoin is started"), NULL);

  pinnipede_open_on_start_fb = gtk_label_new (_("label32"));
  gtk_widget_show (pinnipede_open_on_start_fb);
  gtk_box_pack_start (GTK_BOX (hbox9), pinnipede_open_on_start_fb, FALSE, FALSE, 0);

  frame6 = gtk_frame_new (NULL);
  gtk_widget_show (frame6);
  gtk_box_pack_start (GTK_BOX (vbox6), frame6, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame6), 2);

  vbox24 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox24);
  gtk_container_add (GTK_CONTAINER (frame6), vbox24);
  gtk_container_set_border_width (GTK_CONTAINER (vbox24), 1);

  hbox6 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox6);
  gtk_box_pack_start (GTK_BOX (vbox24), hbox6, TRUE, TRUE, 0);

  label19 = gtk_label_new (_("Font family "));
  gtk_widget_show (label19);
  gtk_box_pack_start (GTK_BOX (hbox6), label19, FALSE, FALSE, 0);

  combo1 = gtk_combo_new ();
  g_object_set_data (G_OBJECT (GTK_COMBO (combo1)->popwin),
                     "GladeParentKey", combo1);
  gtk_widget_show (combo1);
  gtk_box_pack_start (GTK_BOX (hbox6), combo1, FALSE, FALSE, 0);
  combo1_items = g_list_append (combo1_items, (gpointer) _("sans"));
  combo1_items = g_list_append (combo1_items, (gpointer) _("verdana"));
  gtk_combo_set_popdown_strings (GTK_COMBO (combo1), combo1_items);
  g_list_free (combo1_items);

  pp_fn_family = GTK_COMBO (combo1)->entry;
  gtk_widget_show (pp_fn_family);

  label20 = gtk_label_new (_("Font size"));
  gtk_widget_show (label20);
  gtk_box_pack_start (GTK_BOX (hbox6), label20, FALSE, FALSE, 0);

  pp_fn_size_adj = gtk_adjustment_new (2, 0, 100, 1, 10, 10);
  pp_fn_size = gtk_spin_button_new (GTK_ADJUSTMENT (pp_fn_size_adj), 1, 0);
  gtk_widget_show (pp_fn_size);
  gtk_box_pack_start (GTK_BOX (hbox6), pp_fn_size, FALSE, FALSE, 0);

  font_bt = gtk_button_new_from_stock ("gtk-select-font");
  gtk_widget_show (font_bt);
  gtk_box_pack_start (GTK_BOX (hbox6), font_bt, FALSE, FALSE, 0);

  hbox18 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox18);
  gtk_box_pack_start (GTK_BOX (vbox24), hbox18, TRUE, TRUE, 0);

  disable_xft_antialiasing = gtk_check_button_new_with_mnemonic (_("Disable antialiasing "));
  gtk_widget_show (disable_xft_antialiasing);
  gtk_box_pack_start (GTK_BOX (hbox18), disable_xft_antialiasing, FALSE, FALSE, 0);

  disable_xft_antialiasing_fb = gtk_label_new (_("label32"));
  gtk_widget_show (disable_xft_antialiasing_fb);
  gtk_box_pack_start (GTK_BOX (hbox18), disable_xft_antialiasing_fb, FALSE, FALSE, 0);

  label18 = gtk_label_new (_("Font"));
  gtk_widget_show (label18);
  gtk_frame_set_label_widget (GTK_FRAME (frame6), label18);

  frame12 = gtk_frame_new (NULL);
  gtk_widget_show (frame12);
  gtk_box_pack_start (GTK_BOX (vbox6), frame12, FALSE, FALSE, 0);

  hbox42 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox42);
  gtk_container_add (GTK_CONTAINER (frame12), hbox42);
  gtk_container_set_border_width (GTK_CONTAINER (hbox42), 1);

  hbox43 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox43);
  gtk_box_pack_start (GTK_BOX (hbox42), hbox43, TRUE, TRUE, 0);

  label107 = gtk_label_new (_("Tabs position "));
  gtk_widget_show (label107);
  gtk_box_pack_start (GTK_BOX (hbox43), label107, FALSE, FALSE, 0);

  pp_tabs_pos = gtk_option_menu_new ();
  gtk_widget_show (pp_tabs_pos);
  gtk_box_pack_start (GTK_BOX (hbox43), pp_tabs_pos, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (pp_tabs_pos), 3);

  menu3 = gtk_menu_new ();

  bottom1 = gtk_menu_item_new_with_mnemonic (_("bottom"));
  gtk_widget_show (bottom1);
  gtk_container_add (GTK_CONTAINER (menu3), bottom1);

  left1 = gtk_menu_item_new_with_mnemonic (_("left"));
  gtk_widget_show (left1);
  gtk_container_add (GTK_CONTAINER (menu3), left1);

  right1 = gtk_menu_item_new_with_mnemonic (_("right"));
  gtk_widget_show (right1);
  gtk_container_add (GTK_CONTAINER (menu3), right1);

  gtk_option_menu_set_menu (GTK_OPTION_MENU (pp_tabs_pos), menu3);

  vbox26 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox26);
  gtk_box_pack_start (GTK_BOX (hbox42), vbox26, TRUE, TRUE, 0);

  hbox10 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox10);
  gtk_box_pack_start (GTK_BOX (vbox26), hbox10, TRUE, TRUE, 0);

  pp_use_classical_tabs = gtk_check_button_new_with_mnemonic (_("Use 'classical' tabs behaviour "));
  gtk_widget_show (pp_use_classical_tabs);
  gtk_box_pack_start (GTK_BOX (hbox10), pp_use_classical_tabs, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, pp_use_classical_tabs, _("if you think that the default behaviour of the tabs sucks.."), NULL);

  pp_use_classical_tabs_fb = gtk_label_new (_("label32"));
  gtk_widget_show (pp_use_classical_tabs_fb);
  gtk_box_pack_start (GTK_BOX (hbox10), pp_use_classical_tabs_fb, FALSE, FALSE, 0);

  hbox11 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox11);
  gtk_box_pack_start (GTK_BOX (vbox26), hbox11, TRUE, TRUE, 0);

  pp_use_colored_tabs = gtk_check_button_new_with_mnemonic (_("Colored tabs "));
  gtk_widget_show (pp_use_colored_tabs);
  gtk_box_pack_start (GTK_BOX (hbox11), pp_use_colored_tabs, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, pp_use_colored_tabs, _("if used, the \"tabs\" will be colored accordingly to the background color of the messages in the pinnipede"), NULL);

  pp_use_colored_tabs_fb = gtk_label_new (_("label32"));
  gtk_widget_show (pp_use_colored_tabs_fb);
  gtk_box_pack_start (GTK_BOX (hbox11), pp_use_colored_tabs_fb, FALSE, FALSE, 0);

  label106 = gtk_label_new (_("tabs"));
  gtk_widget_show (label106);
  gtk_frame_set_label_widget (GTK_FRAME (frame12), label106);

  hbox12 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox12);
  gtk_box_pack_start (GTK_BOX (vbox6), hbox12, TRUE, TRUE, 0);

  hungry_boitakon = gtk_check_button_new_with_mnemonic (_("Very Hungry boitakon (eats answers to messages in boitakon) "));
  gtk_widget_show (hungry_boitakon);
  gtk_box_pack_start (GTK_BOX (hbox12), hungry_boitakon, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, hungry_boitakon, _("If a message replies to a message in the hungry boitakon and another one which is not in the boitakon, it will be put in the boitakon only if this option is toggled"), NULL);

  hungry_boitakon_fb = gtk_label_new (_("label32"));
  gtk_widget_show (hungry_boitakon_fb);
  gtk_box_pack_start (GTK_BOX (hbox12), hungry_boitakon_fb, FALSE, FALSE, 0);

  hbox23 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox23);
  gtk_box_pack_start (GTK_BOX (vbox6), hbox23, TRUE, TRUE, 0);

  auto_swallow = gtk_check_button_new_with_mnemonic (_("Auto-swallow the dock applet (disable if you want wmcoincoin as a real dock app) "));
  gtk_widget_show (auto_swallow);
  gtk_box_pack_start (GTK_BOX (hbox23), auto_swallow, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, auto_swallow, _("When enabled, the 64x64 dockapp will be embedded into the pinnipede"), NULL);

  auto_swallow_fb = gtk_label_new (_("label32"));
  gtk_widget_show (auto_swallow_fb);
  gtk_box_pack_start (GTK_BOX (hbox23), auto_swallow_fb, FALSE, FALSE, 0);

  hbox32 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox32);
  gtk_box_pack_start (GTK_BOX (vbox6), hbox32, TRUE, TRUE, 0);

  enable_troll_detector = gtk_check_button_new_with_mnemonic (_("Enable the troll-detector "));
  gtk_widget_show (enable_troll_detector);
  gtk_box_pack_start (GTK_BOX (hbox32), enable_troll_detector, FALSE, FALSE, 0);

  enable_troll_detector_fb = gtk_label_new (_("enable_troll_detector"));
  gtk_widget_show (enable_troll_detector_fb);
  gtk_box_pack_start (GTK_BOX (hbox32), enable_troll_detector_fb, FALSE, FALSE, 0);

  hbox2 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox2);
  gtk_box_pack_start (GTK_BOX (vbox6), hbox2, FALSE, FALSE, 0);

  pp_show_sec_mode = gtk_check_button_new_with_mnemonic (_("Show seconds even when unnecessary "));
  gtk_widget_show (pp_show_sec_mode);
  gtk_box_pack_start (GTK_BOX (hbox2), pp_show_sec_mode, FALSE, FALSE, 0);

  pp_show_sec_mode_fb = gtk_label_new (_("pp_show_sec_mode"));
  gtk_widget_show (pp_show_sec_mode_fb);
  gtk_box_pack_start (GTK_BOX (hbox2), pp_show_sec_mode_fb, FALSE, FALSE, 0);

  label16 = gtk_label_new (_("<b>Global settings</b>"));
  gtk_widget_show (label16);
  gtk_frame_set_label_widget (GTK_FRAME (frame4), label16);
  gtk_label_set_use_markup (GTK_LABEL (label16), TRUE);

  hbox36 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox36);
  gtk_box_pack_start (GTK_BOX (vbox5), hbox36, TRUE, TRUE, 0);

  image15 = create_pixmap (global_pinnipede_options_dialog, "cbronson.jpg");
  gtk_widget_show (image15);
  gtk_box_pack_start (GTK_BOX (hbox36), image15, FALSE, FALSE, 0);

  label95 = gtk_label_new (_("Hello, this is Charles Bronson. I wish you a good coincoin"));
  gtk_widget_show (label95);
  gtk_box_pack_start (GTK_BOX (hbox36), label95, FALSE, FALSE, 0);

  label87 = gtk_label_new (_("Appearance"));
  gtk_widget_show (label87);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 0), label87);

  vbox17 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox17);
  gtk_container_add (GTK_CONTAINER (notebook1), vbox17);

  table6 = gtk_table_new (2, 3, FALSE);
  gtk_widget_show (table6);
  gtk_box_pack_start (GTK_BOX (vbox17), table6, FALSE, TRUE, 0);

  label81 = gtk_label_new (_("Main Browser"));
  gtk_widget_show (label81);
  gtk_table_attach (GTK_TABLE (table6), label81, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label81), 0, 0.5);

  label82 = gtk_label_new (_("Secondary Browser"));
  gtk_widget_show (label82);
  gtk_table_attach (GTK_TABLE (table6), label82, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label82), 0, 0.5);

  combo2 = gtk_combo_new ();
  g_object_set_data (G_OBJECT (GTK_COMBO (combo2)->popwin),
                     "GladeParentKey", combo2);
  gtk_widget_show (combo2);
  gtk_table_attach (GTK_TABLE (table6), combo2, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  combo2_items = g_list_append (combo2_items, (gpointer) _("xdg-open %s &"));
  gtk_combo_set_popdown_strings (GTK_COMBO (combo2), combo2_items);
  g_list_free (combo2_items);

  browser_cmd = GTK_COMBO (combo2)->entry;
  gtk_widget_show (browser_cmd);
  gtk_widget_set_size_request (browser_cmd, 400, -1);

  combo3 = gtk_combo_new ();
  g_object_set_data (G_OBJECT (GTK_COMBO (combo3)->popwin),
                     "GladeParentKey", combo3);
  gtk_widget_show (combo3);
  gtk_table_attach (GTK_TABLE (table6), combo3, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  combo3_items = g_list_append (combo3_items, (gpointer) _("xdg-open %s &"));
  gtk_combo_set_popdown_strings (GTK_COMBO (combo3), combo3_items);
  g_list_free (combo3_items);

  browser2_cmd = GTK_COMBO (combo3)->entry;
  gtk_widget_show (browser2_cmd);

  browser_cmd_fb = gtk_label_new (_("label83"));
  gtk_widget_show (browser_cmd_fb);
  gtk_table_attach (GTK_TABLE (table6), browser_cmd_fb, 2, 3, 0, 1,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 1, 0);
  gtk_widget_set_size_request (browser_cmd_fb, 80, -1);
  gtk_label_set_justify (GTK_LABEL (browser_cmd_fb), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (browser_cmd_fb), 0, 0.5);

  browser2_cmd_fb = gtk_label_new (_("label84"));
  gtk_widget_show (browser2_cmd_fb);
  gtk_table_attach (GTK_TABLE (table6), browser2_cmd_fb, 2, 3, 1, 2,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 1, 0);
  gtk_widget_set_size_request (browser2_cmd_fb, 80, -1);
  gtk_label_set_justify (GTK_LABEL (browser2_cmd_fb), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (browser2_cmd_fb), 0, 0.5);

  label85 = gtk_label_new (_("<span size=\"medium\">These options allows you to launch an external browser from wmcoincoin, this is used for reading the news, the comments detected by the flamophone, the personnal messages, the [url]s of the pinnipede teletype.\n<b>be careful</b>: this kind of 'external' command might be a great source of vulnerability since the urls can contain ANY caracter (think of 'http://plop.org; reboot' ..\nFor this reason, dangerous caracter are carefully escapped by wmcc before calling the external browser\nBy default, no browser is selected. \nIn the command, the <b>%s</b> is remplaced by the <b>escaped URL</b>. <u>Do not quote it</u>, or your browser will have problems to read urls containg character such as '&amp;', '$' etc. Do not forget to put an '&amp;' at the end of the command line or wmcc will freeze until the browser is closed.</span>"));
  gtk_widget_show (label85);
  gtk_box_pack_start (GTK_BOX (vbox17), label85, FALSE, FALSE, 0);
  gtk_label_set_use_markup (GTK_LABEL (label85), TRUE);
  gtk_label_set_line_wrap (GTK_LABEL (label85), TRUE);

  label88 = gtk_label_new (_("Browser"));
  gtk_widget_show (label88);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 1), label88);

  vbox19 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox19);
  gtk_container_add (GTK_CONTAINER (notebook1), vbox19);

  hbox33 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox33);
  gtk_box_pack_start (GTK_BOX (vbox19), hbox33, FALSE, TRUE, 0);

  image14 = create_pixmap (global_pinnipede_options_dialog, "totoz.xpm");
  gtk_widget_show (image14);
  gtk_box_pack_start (GTK_BOX (hbox33), image14, FALSE, FALSE, 0);

  vbox20 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox20);
  gtk_box_pack_start (GTK_BOX (hbox33), vbox20, TRUE, TRUE, 0);

  hbox34 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox34);
  gtk_box_pack_start (GTK_BOX (vbox20), hbox34, FALSE, FALSE, 0);

  board_enable_hfr_pictures = gtk_check_button_new_with_mnemonic (_("Enable this feature "));
  gtk_widget_show (board_enable_hfr_pictures);
  gtk_box_pack_start (GTK_BOX (hbox34), board_enable_hfr_pictures, FALSE, FALSE, 0);

  board_enable_hfr_pictures_fb = gtk_label_new (_("label98"));
  gtk_widget_show (board_enable_hfr_pictures_fb);
  gtk_box_pack_start (GTK_BOX (hbox34), board_enable_hfr_pictures_fb, FALSE, FALSE, 0);

  hbox35 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox35);
  gtk_box_pack_start (GTK_BOX (vbox20), hbox35, TRUE, TRUE, 0);

  board_auto_dl_pictures = gtk_check_button_new_with_mnemonic (_("Automatically download [:totoz] pictures \n(may fill your harddrive with dumb GIFs) "));
  gtk_widget_show (board_auto_dl_pictures);
  gtk_box_pack_start (GTK_BOX (hbox35), board_auto_dl_pictures, FALSE, FALSE, 0);

  board_auto_dl_pictures_fb = gtk_label_new (_("label97"));
  gtk_widget_show (board_auto_dl_pictures_fb);
  gtk_box_pack_start (GTK_BOX (hbox35), board_auto_dl_pictures_fb, FALSE, FALSE, 0);

  hseparator7 = gtk_hseparator_new ();
  gtk_widget_show (hseparator7);
  gtk_box_pack_start (GTK_BOX (vbox19), hseparator7, FALSE, FALSE, 0);

  hbox7 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox7);
  gtk_box_pack_start (GTK_BOX (vbox19), hbox7, TRUE, TRUE, 0);

  label21 = gtk_label_new (_("Totoz server (use %s as a\nplaceholder for the totoz name)"));
  gtk_widget_show (label21);
  gtk_box_pack_start (GTK_BOX (hbox7), label21, FALSE, FALSE, 0);

  combo4 = gtk_combo_new ();
  g_object_set_data (G_OBJECT (GTK_COMBO (combo4)->popwin),
                     "GladeParentKey", combo4);
  gtk_widget_show (combo4);
  gtk_box_pack_start (GTK_BOX (hbox7), combo4, FALSE, FALSE, 0);
  combo4_items = g_list_append (combo4_items, (gpointer) _("https://totoz.eu/gif/%s.gif"));
  combo4_items = g_list_append (combo4_items, (gpointer) _("https://nsfw.totoz.eu/gif/%s.gif"));
  combo4_items = g_list_append (combo4_items, (gpointer) _("https://totoz.moul.es/gif/%s.gif"));
  combo4_items = g_list_append (combo4_items, (gpointer) _("https://nsfw.totoz.moul.es/gif/%s.gif"));
  combo4_items = g_list_append (combo4_items, (gpointer) _("https://claudex.be/sfwttz/%s.gif"));
  combo4_items = g_list_append (combo4_items, (gpointer) _("https://claudex.be/ttz/%s.gif"));
  gtk_combo_set_popdown_strings (GTK_COMBO (combo4), combo4_items);
  g_list_free (combo4_items);

  board_totoz_server = GTK_COMBO (combo4)->entry;
  gtk_widget_show (board_totoz_server);

  label94 = gtk_label_new (_("The totoz module requires wmcoincoin_player support. It searches for occurences of [:totoz] etc in the pinnipede, and displays a correspounding picture from the set of smileys of http://totoz.eu\n\nThis pictures may be bookmarked in the pinnipede (via right clic), and the bookmark ( stored in ~/.wmcoincoin/totoz/bookmarks.{txt,html} ) can be opened from the totoz button in the palmipede."));
  gtk_widget_show (label94);
  gtk_box_pack_start (GTK_BOX (vbox19), label94, FALSE, FALSE, 0);
  gtk_label_set_line_wrap (GTK_LABEL (label94), TRUE);

  label92 = gtk_label_new (_("Totoz"));
  gtk_widget_show (label92);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 2), label92);

  vbox18 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox18);
  gtk_container_add (GTK_CONTAINER (notebook1), vbox18);

  hunt_opened = gtk_check_button_new_with_mnemonic (_("Enable balltrap on startup"));
  gtk_widget_show (hunt_opened);
  gtk_box_pack_start (GTK_BOX (vbox18), hunt_opened, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, hunt_opened, _("this is the global switch for the balltrap (look at the duck in the pinnipede button bar)"), NULL);

  hbox31 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox31);
  gtk_box_pack_start (GTK_BOX (vbox18), hbox31, FALSE, FALSE, 0);

  label90 = gtk_label_new (_("Max. number of simultaneous ducks"));
  gtk_widget_show (label90);
  gtk_box_pack_start (GTK_BOX (hbox31), label90, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (label90), 3, 0);

  hunt_max_duck_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  hunt_max_duck = gtk_spin_button_new (GTK_ADJUSTMENT (hunt_max_duck_adj), 1, 0);
  gtk_widget_show (hunt_max_duck);
  gtk_box_pack_start (GTK_BOX (hbox31), hunt_max_duck, FALSE, FALSE, 0);

  hseparator6 = gtk_hseparator_new ();
  gtk_widget_show (hseparator6);
  gtk_box_pack_start (GTK_BOX (vbox18), hseparator6, FALSE, FALSE, 0);

  label91 = gtk_label_new (_("Hunting is fun.  Everybody enjoys shooting ducks with a bazooka. Lower your stress and improve your productivity with the balltrap module.\n\nNote that since X sucks with respect to moving windows, the balltrap may consume all your CPU, especially when ducks are flying over a slow-refresh window.. \n\nThe balltrap can be disabled for some sites, and enabled on other sites (see the switch in the site settings dialog). For example, it is recommended to disable the balltrap on woof.lu (or at least to avoid hammering the server with hundreds of pan!pan!)\n\nTraining is possible with plastic ducks, launched by a left clic on the dock applet. A right clic kills silently all displayed ducks."));
  gtk_widget_show (label91);
  gtk_box_pack_start (GTK_BOX (vbox18), label91, FALSE, FALSE, 0);
  gtk_label_set_line_wrap (GTK_LABEL (label91), TRUE);

  label89 = gtk_label_new (_("Balltrap"));
  gtk_widget_show (label89);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 3), label89);

  dialog_action_area3 = GTK_DIALOG (global_pinnipede_options_dialog)->action_area;
  gtk_widget_show (dialog_action_area3);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area3), GTK_BUTTONBOX_END);

  cancel_bt = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (cancel_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (global_pinnipede_options_dialog), cancel_bt, GTK_RESPONSE_CANCEL);
  GTK_WIDGET_SET_FLAGS (cancel_bt, GTK_CAN_DEFAULT);

  apply_bt = gtk_button_new_from_stock ("gtk-apply");
  gtk_widget_show (apply_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (global_pinnipede_options_dialog), apply_bt, GTK_RESPONSE_APPLY);
  GTK_WIDGET_SET_FLAGS (apply_bt, GTK_CAN_DEFAULT);

  ok_bt = gtk_button_new_from_stock ("gtk-ok");
  gtk_widget_show (ok_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (global_pinnipede_options_dialog), ok_bt, GTK_RESPONSE_OK);
  GTK_WIDGET_SET_FLAGS (ok_bt, GTK_CAN_DEFAULT);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (global_pinnipede_options_dialog, global_pinnipede_options_dialog, "global_pinnipede_options_dialog");
  GLADE_HOOKUP_OBJECT_NO_REF (global_pinnipede_options_dialog, dialog_vbox3, "dialog_vbox3");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, notebook1, "notebook1");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, vbox5, "vbox5");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, label15, "label15");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, frame4, "frame4");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, vbox6, "vbox6");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hbox9, "hbox9");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, pinnipede_open_on_start, "pinnipede_open_on_start");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, pinnipede_open_on_start_fb, "pinnipede_open_on_start_fb");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, frame6, "frame6");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, vbox24, "vbox24");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hbox6, "hbox6");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, label19, "label19");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, combo1, "combo1");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, pp_fn_family, "pp_fn_family");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, label20, "label20");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, pp_fn_size, "pp_fn_size");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, font_bt, "font_bt");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hbox18, "hbox18");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, disable_xft_antialiasing, "disable_xft_antialiasing");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, disable_xft_antialiasing_fb, "disable_xft_antialiasing_fb");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, label18, "label18");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, frame12, "frame12");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hbox42, "hbox42");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hbox43, "hbox43");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, label107, "label107");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, pp_tabs_pos, "pp_tabs_pos");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, menu3, "menu3");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, bottom1, "bottom1");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, left1, "left1");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, right1, "right1");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, vbox26, "vbox26");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hbox10, "hbox10");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, pp_use_classical_tabs, "pp_use_classical_tabs");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, pp_use_classical_tabs_fb, "pp_use_classical_tabs_fb");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hbox11, "hbox11");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, pp_use_colored_tabs, "pp_use_colored_tabs");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, pp_use_colored_tabs_fb, "pp_use_colored_tabs_fb");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, label106, "label106");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hbox12, "hbox12");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hungry_boitakon, "hungry_boitakon");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hungry_boitakon_fb, "hungry_boitakon_fb");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hbox23, "hbox23");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, auto_swallow, "auto_swallow");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, auto_swallow_fb, "auto_swallow_fb");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hbox32, "hbox32");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, enable_troll_detector, "enable_troll_detector");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, enable_troll_detector_fb, "enable_troll_detector_fb");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hbox2, "hbox2");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, pp_show_sec_mode, "pp_show_sec_mode");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, pp_show_sec_mode_fb, "pp_show_sec_mode_fb");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, label16, "label16");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hbox36, "hbox36");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, image15, "image15");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, label95, "label95");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, label87, "label87");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, vbox17, "vbox17");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, table6, "table6");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, label81, "label81");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, label82, "label82");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, combo2, "combo2");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, browser_cmd, "browser_cmd");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, combo3, "combo3");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, browser2_cmd, "browser2_cmd");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, browser_cmd_fb, "browser_cmd_fb");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, browser2_cmd_fb, "browser2_cmd_fb");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, label85, "label85");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, label88, "label88");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, vbox19, "vbox19");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hbox33, "hbox33");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, image14, "image14");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, vbox20, "vbox20");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hbox34, "hbox34");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, board_enable_hfr_pictures, "board_enable_hfr_pictures");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, board_enable_hfr_pictures_fb, "board_enable_hfr_pictures_fb");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hbox35, "hbox35");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, board_auto_dl_pictures, "board_auto_dl_pictures");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, board_auto_dl_pictures_fb, "board_auto_dl_pictures_fb");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hseparator7, "hseparator7");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hbox7, "hbox7");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, label21, "label21");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, combo4, "combo4");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, board_totoz_server, "board_totoz_server");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, label94, "label94");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, label92, "label92");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, vbox18, "vbox18");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hunt_opened, "hunt_opened");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hbox31, "hbox31");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, label90, "label90");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hunt_max_duck, "hunt_max_duck");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, hseparator6, "hseparator6");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, label91, "label91");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, label89, "label89");
  GLADE_HOOKUP_OBJECT_NO_REF (global_pinnipede_options_dialog, dialog_action_area3, "dialog_action_area3");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, cancel_bt, "cancel_bt");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, apply_bt, "apply_bt");
  GLADE_HOOKUP_OBJECT (global_pinnipede_options_dialog, ok_bt, "ok_bt");
  GLADE_HOOKUP_OBJECT_NO_REF (global_pinnipede_options_dialog, tooltips, "tooltips");

  return global_pinnipede_options_dialog;
}

GtkWidget*
create_edit_dialog (void)
{
  GtkWidget *edit_dialog;
  GtkWidget *dialog_vbox4;
  GtkWidget *vbox8;
  GtkWidget *label38;
  GtkWidget *scrolledwindow3;
  GtkWidget *textview;
  GtkWidget *dialog_action_area4;
  GtkWidget *cancel_bt;
  GtkWidget *apply_bt;
  GtkWidget *ok_bt;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  edit_dialog = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (edit_dialog), _("Options edit"));
  gtk_window_set_modal (GTK_WINDOW (edit_dialog), TRUE);
  gtk_window_set_default_size (GTK_WINDOW (edit_dialog), 600, 450);
  gtk_window_set_type_hint (GTK_WINDOW (edit_dialog), GDK_WINDOW_TYPE_HINT_DIALOG);

  dialog_vbox4 = GTK_DIALOG (edit_dialog)->vbox;
  gtk_widget_show (dialog_vbox4);

  vbox8 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox8);
  gtk_box_pack_start (GTK_BOX (dialog_vbox4), vbox8, TRUE, TRUE, 0);

  label38 = gtk_label_new (_("wmccc \"do it yourself\" flavor"));
  gtk_widget_show (label38);
  gtk_box_pack_start (GTK_BOX (vbox8), label38, FALSE, FALSE, 0);

  scrolledwindow3 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow3);
  gtk_box_pack_start (GTK_BOX (vbox8), scrolledwindow3, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow3), GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);

  textview = gtk_text_view_new ();
  gtk_widget_show (textview);
  gtk_container_add (GTK_CONTAINER (scrolledwindow3), textview);

  dialog_action_area4 = GTK_DIALOG (edit_dialog)->action_area;
  gtk_widget_show (dialog_action_area4);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area4), GTK_BUTTONBOX_END);

  cancel_bt = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (cancel_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (edit_dialog), cancel_bt, GTK_RESPONSE_CANCEL);
  GTK_WIDGET_SET_FLAGS (cancel_bt, GTK_CAN_DEFAULT);

  apply_bt = gtk_button_new_from_stock ("gtk-apply");
  gtk_widget_show (apply_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (edit_dialog), apply_bt, GTK_RESPONSE_APPLY);
  GTK_WIDGET_SET_FLAGS (apply_bt, GTK_CAN_DEFAULT);
  gtk_tooltips_set_tip (tooltips, apply_bt, _("Apply changes to wmcoincoin but do not save them"), NULL);

  ok_bt = gtk_button_new_from_stock ("gtk-save");
  gtk_widget_show (ok_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (edit_dialog), ok_bt, GTK_RESPONSE_OK);
  GTK_WIDGET_SET_FLAGS (ok_bt, GTK_CAN_DEFAULT);
  gtk_tooltips_set_tip (tooltips, ok_bt, _("Save changes to the options file, but do not apply them"), NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (edit_dialog, edit_dialog, "edit_dialog");
  GLADE_HOOKUP_OBJECT_NO_REF (edit_dialog, dialog_vbox4, "dialog_vbox4");
  GLADE_HOOKUP_OBJECT (edit_dialog, vbox8, "vbox8");
  GLADE_HOOKUP_OBJECT (edit_dialog, label38, "label38");
  GLADE_HOOKUP_OBJECT (edit_dialog, scrolledwindow3, "scrolledwindow3");
  GLADE_HOOKUP_OBJECT (edit_dialog, textview, "textview");
  GLADE_HOOKUP_OBJECT_NO_REF (edit_dialog, dialog_action_area4, "dialog_action_area4");
  GLADE_HOOKUP_OBJECT (edit_dialog, cancel_bt, "cancel_bt");
  GLADE_HOOKUP_OBJECT (edit_dialog, apply_bt, "apply_bt");
  GLADE_HOOKUP_OBJECT (edit_dialog, ok_bt, "ok_bt");
  GLADE_HOOKUP_OBJECT_NO_REF (edit_dialog, tooltips, "tooltips");

  return edit_dialog;
}

GtkWidget*
create_bronson_wizard (void)
{
  GtkWidget *bronson_wizard;
  GtkWidget *dialog_vbox5;
  GtkWidget *vbox9;
  GtkWidget *hbox15;
  GtkWidget *image5;
  GtkWidget *label40;
  GtkWidget *hseparator1;
  GtkWidget *hbox16;
  GtkWidget *label41;
  GtkWidget *vbox11;
  GtkWidget *wizard_new_board_bt;
  GtkWidget *alignment8;
  GtkWidget *hbox28;
  GtkWidget *image11;
  GtkWidget *label77;
  GtkWidget *wizard_new_feed_bt;
  GtkWidget *alignment7;
  GtkWidget *hbox27;
  GtkWidget *image10;
  GtkWidget *label76;
  GtkWidget *wizard_new_pop_bt;
  GtkWidget *alignment6;
  GtkWidget *hbox26;
  GtkWidget *image9;
  GtkWidget *label75;
  GtkWidget *edit_options_bt;
  GtkWidget *alignment5;
  GtkWidget *hbox25;
  GtkWidget *image8;
  GtkWidget *label74;
  GtkWidget *dialog_action_area5;
  GtkWidget *button2;

  bronson_wizard = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (bronson_wizard), _("the wmccc wizard"));
  gtk_window_set_type_hint (GTK_WINDOW (bronson_wizard), GDK_WINDOW_TYPE_HINT_DIALOG);

  dialog_vbox5 = GTK_DIALOG (bronson_wizard)->vbox;
  gtk_widget_show (dialog_vbox5);

  vbox9 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox9);
  gtk_box_pack_start (GTK_BOX (dialog_vbox5), vbox9, TRUE, TRUE, 0);

  hbox15 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox15);
  gtk_box_pack_start (GTK_BOX (vbox9), hbox15, FALSE, TRUE, 0);

  image5 = create_pixmap (bronson_wizard, "cbronson.jpg");
  gtk_widget_show (image5);
  gtk_box_pack_start (GTK_BOX (hbox15), image5, FALSE, FALSE, 0);

  label40 = gtk_label_new (_("Hello, I am Charles Bronson and I am going to guide you during the configuration of wmcoincoin.\nDon't fuck with me or I'll kick your ass with a mammoth's cubitus"));
  gtk_widget_show (label40);
  gtk_box_pack_start (GTK_BOX (hbox15), label40, FALSE, FALSE, 8);
  gtk_label_set_line_wrap (GTK_LABEL (label40), TRUE);

  hseparator1 = gtk_hseparator_new ();
  gtk_widget_show (hseparator1);
  gtk_box_pack_start (GTK_BOX (vbox9), hseparator1, TRUE, TRUE, 0);

  hbox16 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox16);
  gtk_box_pack_start (GTK_BOX (vbox9), hbox16, TRUE, TRUE, 0);

  label41 = gtk_label_new (_("Where do you want to go today ?"));
  gtk_widget_show (label41);
  gtk_box_pack_start (GTK_BOX (hbox16), label41, TRUE, FALSE, 0);

  vbox11 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox11);
  gtk_box_pack_start (GTK_BOX (hbox16), vbox11, FALSE, FALSE, 23);

  wizard_new_board_bt = gtk_button_new ();
  gtk_widget_show (wizard_new_board_bt);
  gtk_box_pack_start (GTK_BOX (vbox11), wizard_new_board_bt, FALSE, FALSE, 0);

  alignment8 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment8);
  gtk_container_add (GTK_CONTAINER (wizard_new_board_bt), alignment8);

  hbox28 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox28);
  gtk_container_add (GTK_CONTAINER (alignment8), hbox28);

  image11 = gtk_image_new_from_stock ("gtk-add", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image11);
  gtk_box_pack_start (GTK_BOX (hbox28), image11, FALSE, FALSE, 0);

  label77 = gtk_label_new_with_mnemonic (_("I want to add a new board"));
  gtk_widget_show (label77);
  gtk_box_pack_start (GTK_BOX (hbox28), label77, FALSE, FALSE, 0);

  wizard_new_feed_bt = gtk_button_new ();
  gtk_widget_show (wizard_new_feed_bt);
  gtk_box_pack_start (GTK_BOX (vbox11), wizard_new_feed_bt, FALSE, FALSE, 0);

  alignment7 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment7);
  gtk_container_add (GTK_CONTAINER (wizard_new_feed_bt), alignment7);

  hbox27 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox27);
  gtk_container_add (GTK_CONTAINER (alignment7), hbox27);

  image10 = gtk_image_new_from_stock ("gtk-add", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image10);
  gtk_box_pack_start (GTK_BOX (hbox27), image10, FALSE, FALSE, 0);

  label76 = gtk_label_new_with_mnemonic (_("I want to add a new RSS feed"));
  gtk_widget_show (label76);
  gtk_box_pack_start (GTK_BOX (hbox27), label76, FALSE, FALSE, 0);

  wizard_new_pop_bt = gtk_button_new ();
  gtk_widget_show (wizard_new_pop_bt);
  gtk_box_pack_start (GTK_BOX (vbox11), wizard_new_pop_bt, FALSE, FALSE, 0);

  alignment6 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment6);
  gtk_container_add (GTK_CONTAINER (wizard_new_pop_bt), alignment6);

  hbox26 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox26);
  gtk_container_add (GTK_CONTAINER (alignment6), hbox26);

  image9 = gtk_image_new_from_stock ("gtk-add", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image9);
  gtk_box_pack_start (GTK_BOX (hbox26), image9, FALSE, FALSE, 0);

  label75 = gtk_label_new_with_mnemonic (_("I want to add a new POP3 account"));
  gtk_widget_show (label75);
  gtk_box_pack_start (GTK_BOX (hbox26), label75, FALSE, FALSE, 0);

  edit_options_bt = gtk_button_new ();
  gtk_widget_show (edit_options_bt);
  gtk_box_pack_start (GTK_BOX (vbox11), edit_options_bt, FALSE, FALSE, 0);

  alignment5 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment5);
  gtk_container_add (GTK_CONTAINER (edit_options_bt), alignment5);

  hbox25 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox25);
  gtk_container_add (GTK_CONTAINER (alignment5), hbox25);

  image8 = gtk_image_new_from_stock ("gtk-convert", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image8);
  gtk_box_pack_start (GTK_BOX (hbox25), image8, FALSE, FALSE, 0);

  label74 = gtk_label_new_with_mnemonic (_("I want to edit the options"));
  gtk_widget_show (label74);
  gtk_box_pack_start (GTK_BOX (hbox25), label74, FALSE, FALSE, 0);

  dialog_action_area5 = GTK_DIALOG (bronson_wizard)->action_area;
  gtk_widget_show (dialog_action_area5);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area5), GTK_BUTTONBOX_END);

  button2 = gtk_button_new_from_stock ("gtk-close");
  gtk_widget_show (button2);
  gtk_dialog_add_action_widget (GTK_DIALOG (bronson_wizard), button2, GTK_RESPONSE_CLOSE);
  GTK_WIDGET_SET_FLAGS (button2, GTK_CAN_DEFAULT);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (bronson_wizard, bronson_wizard, "bronson_wizard");
  GLADE_HOOKUP_OBJECT_NO_REF (bronson_wizard, dialog_vbox5, "dialog_vbox5");
  GLADE_HOOKUP_OBJECT (bronson_wizard, vbox9, "vbox9");
  GLADE_HOOKUP_OBJECT (bronson_wizard, hbox15, "hbox15");
  GLADE_HOOKUP_OBJECT (bronson_wizard, image5, "image5");
  GLADE_HOOKUP_OBJECT (bronson_wizard, label40, "label40");
  GLADE_HOOKUP_OBJECT (bronson_wizard, hseparator1, "hseparator1");
  GLADE_HOOKUP_OBJECT (bronson_wizard, hbox16, "hbox16");
  GLADE_HOOKUP_OBJECT (bronson_wizard, label41, "label41");
  GLADE_HOOKUP_OBJECT (bronson_wizard, vbox11, "vbox11");
  GLADE_HOOKUP_OBJECT (bronson_wizard, wizard_new_board_bt, "wizard_new_board_bt");
  GLADE_HOOKUP_OBJECT (bronson_wizard, alignment8, "alignment8");
  GLADE_HOOKUP_OBJECT (bronson_wizard, hbox28, "hbox28");
  GLADE_HOOKUP_OBJECT (bronson_wizard, image11, "image11");
  GLADE_HOOKUP_OBJECT (bronson_wizard, label77, "label77");
  GLADE_HOOKUP_OBJECT (bronson_wizard, wizard_new_feed_bt, "wizard_new_feed_bt");
  GLADE_HOOKUP_OBJECT (bronson_wizard, alignment7, "alignment7");
  GLADE_HOOKUP_OBJECT (bronson_wizard, hbox27, "hbox27");
  GLADE_HOOKUP_OBJECT (bronson_wizard, image10, "image10");
  GLADE_HOOKUP_OBJECT (bronson_wizard, label76, "label76");
  GLADE_HOOKUP_OBJECT (bronson_wizard, wizard_new_pop_bt, "wizard_new_pop_bt");
  GLADE_HOOKUP_OBJECT (bronson_wizard, alignment6, "alignment6");
  GLADE_HOOKUP_OBJECT (bronson_wizard, hbox26, "hbox26");
  GLADE_HOOKUP_OBJECT (bronson_wizard, image9, "image9");
  GLADE_HOOKUP_OBJECT (bronson_wizard, label75, "label75");
  GLADE_HOOKUP_OBJECT (bronson_wizard, edit_options_bt, "edit_options_bt");
  GLADE_HOOKUP_OBJECT (bronson_wizard, alignment5, "alignment5");
  GLADE_HOOKUP_OBJECT (bronson_wizard, hbox25, "hbox25");
  GLADE_HOOKUP_OBJECT (bronson_wizard, image8, "image8");
  GLADE_HOOKUP_OBJECT (bronson_wizard, label74, "label74");
  GLADE_HOOKUP_OBJECT_NO_REF (bronson_wizard, dialog_action_area5, "dialog_action_area5");
  GLADE_HOOKUP_OBJECT (bronson_wizard, button2, "button2");

  return bronson_wizard;
}

GtkWidget*
create_sitelist_dialog (void)
{
  GtkWidget *sitelist_dialog;
  GtkWidget *dialog_vbox7;
  GtkWidget *vbox12;
  GtkWidget *hseparator2;
  GtkWidget *title_lbl;
  GtkWidget *label71;
  GtkWidget *hbox17;
  GtkWidget *vseparator2;
  GtkWidget *scrolledwindow4;
  GtkWidget *treeview;
  GtkWidget *vseparator1;
  GtkWidget *vbox22;
  GtkWidget *frame10;
  GtkWidget *vbox13;
  GtkWidget *edit_bt;
  GtkWidget *colors_bt;
  GtkWidget *alignment14;
  GtkWidget *hbox41;
  GtkWidget *image20;
  GtkWidget *label105;
  GtkWidget *proxy_bt;
  GtkWidget *remove_bt;
  GtkWidget *alignment13;
  GtkWidget *hbox40;
  GtkWidget *image19;
  GtkWidget *label_remoev;
  GtkWidget *label103;
  GtkWidget *frame11;
  GtkWidget *vbox23;
  GtkWidget *new_site_bt;
  GtkWidget *alignment11;
  GtkWidget *hbox38;
  GtkWidget *image17;
  GtkWidget *label102;
  GtkWidget *pinnipede_settings_bt;
  GtkWidget *alignment12;
  GtkWidget *hbox39;
  GtkWidget *image18;
  GtkWidget *label_pini;
  GtkWidget *edit_options_bt;
  GtkWidget *alignment4;
  GtkWidget *hbox24;
  GtkWidget *image7;
  GtkWidget *label73;
  GtkWidget *label104;
  GtkWidget *hseparator3;
  GtkWidget *dialog_action_area7;
  GtkWidget *cancel_bt;
  GtkWidget *apply_bt;
  GtkWidget *save_bt;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  sitelist_dialog = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (sitelist_dialog), _("WMCCC"));
  gtk_window_set_position (GTK_WINDOW (sitelist_dialog), GTK_WIN_POS_CENTER);
  gtk_window_set_default_size (GTK_WINDOW (sitelist_dialog), 640, 460);
  gtk_window_set_type_hint (GTK_WINDOW (sitelist_dialog), GDK_WINDOW_TYPE_HINT_DIALOG);

  dialog_vbox7 = GTK_DIALOG (sitelist_dialog)->vbox;
  gtk_widget_show (dialog_vbox7);

  vbox12 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox12);
  gtk_box_pack_start (GTK_BOX (dialog_vbox7), vbox12, TRUE, TRUE, 0);

  hseparator2 = gtk_hseparator_new ();
  gtk_widget_show (hseparator2);
  gtk_box_pack_start (GTK_BOX (vbox12), hseparator2, FALSE, FALSE, 0);

  title_lbl = gtk_label_new (_("Editing options file:"));
  gtk_widget_show (title_lbl);
  gtk_box_pack_start (GTK_BOX (vbox12), title_lbl, FALSE, FALSE, 0);
  gtk_label_set_use_markup (GTK_LABEL (title_lbl), TRUE);

  label71 = gtk_label_new (_("<span size=\"small\"><b>PLEASE DO A SAUVEGARDE OF YOUR OPTIONS IT IS TOUT A FAIT POSSIBLE \nTHAT THE NEW WMCCC FUCK YOUR OPTIONS,\nYOU HAVE BEEN WARNED</b></span>"));
  gtk_widget_show (label71);
  gtk_box_pack_start (GTK_BOX (vbox12), label71, FALSE, FALSE, 0);
  gtk_label_set_use_markup (GTK_LABEL (label71), TRUE);

  hbox17 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox17);
  gtk_box_pack_start (GTK_BOX (vbox12), hbox17, TRUE, TRUE, 0);

  vseparator2 = gtk_vseparator_new ();
  gtk_widget_show (vseparator2);
  gtk_box_pack_start (GTK_BOX (hbox17), vseparator2, FALSE, FALSE, 0);

  scrolledwindow4 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow4);
  gtk_box_pack_start (GTK_BOX (hbox17), scrolledwindow4, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow4), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  treeview = gtk_tree_view_new ();
  gtk_widget_show (treeview);
  gtk_container_add (GTK_CONTAINER (scrolledwindow4), treeview);

  vseparator1 = gtk_vseparator_new ();
  gtk_widget_show (vseparator1);
  gtk_box_pack_start (GTK_BOX (hbox17), vseparator1, FALSE, FALSE, 0);

  vbox22 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox22);
  gtk_box_pack_start (GTK_BOX (hbox17), vbox22, FALSE, FALSE, 0);

  frame10 = gtk_frame_new (NULL);
  gtk_widget_show (frame10);
  gtk_box_pack_start (GTK_BOX (vbox22), frame10, FALSE, FALSE, 0);

  vbox13 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox13);
  gtk_container_add (GTK_CONTAINER (frame10), vbox13);

  edit_bt = gtk_button_new_with_mnemonic (_("Edit the \nselected sites"));
  gtk_widget_show (edit_bt);
  gtk_box_pack_start (GTK_BOX (vbox13), edit_bt, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, edit_bt, _("Change various settings for the selected sites (name and aliases, backend, etc)"), NULL);

  colors_bt = gtk_button_new ();
  gtk_widget_show (colors_bt);
  gtk_box_pack_start (GTK_BOX (vbox13), colors_bt, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, colors_bt, _("Change color settings (background etc) for the selected sites"), NULL);

  alignment14 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment14);
  gtk_container_add (GTK_CONTAINER (colors_bt), alignment14);

  hbox41 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox41);
  gtk_container_add (GTK_CONTAINER (alignment14), hbox41);

  image20 = gtk_image_new_from_stock ("gtk-select-color", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image20);
  gtk_box_pack_start (GTK_BOX (hbox41), image20, FALSE, FALSE, 0);

  label105 = gtk_label_new_with_mnemonic (_("Change colors for\n selected sites"));
  gtk_widget_show (label105);
  gtk_box_pack_start (GTK_BOX (hbox41), label105, FALSE, FALSE, 0);

  proxy_bt = gtk_button_new_with_mnemonic (_("Proxy settings"));
  gtk_widget_show (proxy_bt);
  gtk_box_pack_start (GTK_BOX (vbox13), proxy_bt, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, proxy_bt, _("Change proxy settings for the selected sites"), NULL);

  remove_bt = gtk_button_new ();
  gtk_widget_show (remove_bt);
  gtk_box_pack_start (GTK_BOX (vbox13), remove_bt, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, remove_bt, _("Removes permanently the site -- you may prefer to uncheck the check-box in the site list to remove the site temporarily from the pinnipede"), NULL);

  alignment13 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment13);
  gtk_container_add (GTK_CONTAINER (remove_bt), alignment13);

  hbox40 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox40);
  gtk_container_add (GTK_CONTAINER (alignment13), hbox40);

  image19 = gtk_image_new_from_stock ("gtk-remove", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image19);
  gtk_box_pack_start (GTK_BOX (hbox40), image19, FALSE, FALSE, 0);

  label_remoev = gtk_label_new_with_mnemonic (_("Remove the\n selected sites"));
  gtk_widget_show (label_remoev);
  gtk_box_pack_start (GTK_BOX (hbox40), label_remoev, FALSE, FALSE, 0);

  label103 = gtk_label_new (_("Site actions"));
  gtk_widget_show (label103);
  gtk_frame_set_label_widget (GTK_FRAME (frame10), label103);

  frame11 = gtk_frame_new (NULL);
  gtk_widget_show (frame11);
  gtk_box_pack_end (GTK_BOX (vbox22), frame11, FALSE, FALSE, 0);

  vbox23 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox23);
  gtk_container_add (GTK_CONTAINER (frame11), vbox23);

  new_site_bt = gtk_button_new ();
  gtk_widget_show (new_site_bt);
  gtk_box_pack_start (GTK_BOX (vbox23), new_site_bt, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, new_site_bt, _("Create a new site (board, rss, etc), with the help of Charles Bronson"), NULL);

  alignment11 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment11);
  gtk_container_add (GTK_CONTAINER (new_site_bt), alignment11);

  hbox38 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox38);
  gtk_container_add (GTK_CONTAINER (alignment11), hbox38);

  image17 = gtk_image_new_from_stock ("gtk-add", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image17);
  gtk_box_pack_start (GTK_BOX (hbox38), image17, FALSE, FALSE, 0);

  label102 = gtk_label_new_with_mnemonic (_("Insert a new site"));
  gtk_widget_show (label102);
  gtk_box_pack_start (GTK_BOX (hbox38), label102, FALSE, FALSE, 0);

  pinnipede_settings_bt = gtk_button_new ();
  gtk_widget_show (pinnipede_settings_bt);
  gtk_box_pack_start (GTK_BOX (vbox23), pinnipede_settings_bt, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, pinnipede_settings_bt, _("Change various (non site-specific) settings"), NULL);

  alignment12 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment12);
  gtk_container_add (GTK_CONTAINER (pinnipede_settings_bt), alignment12);

  hbox39 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox39);
  gtk_container_add (GTK_CONTAINER (alignment12), hbox39);

  image18 = gtk_image_new_from_stock ("gtk-select-color", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image18);
  gtk_box_pack_start (GTK_BOX (hbox39), image18, FALSE, FALSE, 0);

  label_pini = gtk_label_new_with_mnemonic (_("Pinnipede Settings"));
  gtk_widget_show (label_pini);
  gtk_box_pack_start (GTK_BOX (hbox39), label_pini, FALSE, FALSE, 0);

  edit_options_bt = gtk_button_new ();
  gtk_widget_show (edit_options_bt);
  gtk_box_pack_start (GTK_BOX (vbox23), edit_options_bt, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, edit_options_bt, _("Edit the options as a text file"), NULL);

  alignment4 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment4);
  gtk_container_add (GTK_CONTAINER (edit_options_bt), alignment4);

  hbox24 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox24);
  gtk_container_add (GTK_CONTAINER (alignment4), hbox24);

  image7 = gtk_image_new_from_stock ("gtk-convert", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image7);
  gtk_box_pack_start (GTK_BOX (hbox24), image7, FALSE, FALSE, 0);

  label73 = gtk_label_new_with_mnemonic (_("Do It Yourself"));
  gtk_widget_show (label73);
  gtk_box_pack_start (GTK_BOX (hbox24), label73, FALSE, FALSE, 0);

  label104 = gtk_label_new (_("Global actions"));
  gtk_widget_show (label104);
  gtk_frame_set_label_widget (GTK_FRAME (frame11), label104);

  hseparator3 = gtk_hseparator_new ();
  gtk_widget_show (hseparator3);
  gtk_box_pack_start (GTK_BOX (vbox12), hseparator3, FALSE, FALSE, 0);

  dialog_action_area7 = GTK_DIALOG (sitelist_dialog)->action_area;
  gtk_widget_show (dialog_action_area7);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area7), GTK_BUTTONBOX_END);

  cancel_bt = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (cancel_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (sitelist_dialog), cancel_bt, GTK_RESPONSE_CANCEL);
  GTK_WIDGET_SET_FLAGS (cancel_bt, GTK_CAN_DEFAULT);
  gtk_tooltips_set_tip (tooltips, cancel_bt, _("Ignore changes and exit"), NULL);

  apply_bt = gtk_button_new_from_stock ("gtk-apply");
  gtk_widget_show (apply_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (sitelist_dialog), apply_bt, GTK_RESPONSE_APPLY);
  GTK_WIDGET_SET_FLAGS (apply_bt, GTK_CAN_DEFAULT);
  gtk_tooltips_set_tip (tooltips, apply_bt, _("Apply the changes to wmcc (but the changes are NOT saved in the options file!)"), NULL);

  save_bt = gtk_button_new_from_stock ("gtk-save");
  gtk_widget_show (save_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (sitelist_dialog), save_bt, GTK_RESPONSE_OK);
  GTK_WIDGET_SET_FLAGS (save_bt, GTK_CAN_DEFAULT);
  gtk_tooltips_set_tip (tooltips, save_bt, _("Save and exit (if wmccc was invoked from wmcc, the changes are NOT applied !)"), NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (sitelist_dialog, sitelist_dialog, "sitelist_dialog");
  GLADE_HOOKUP_OBJECT_NO_REF (sitelist_dialog, dialog_vbox7, "dialog_vbox7");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, vbox12, "vbox12");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, hseparator2, "hseparator2");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, title_lbl, "title_lbl");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, label71, "label71");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, hbox17, "hbox17");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, vseparator2, "vseparator2");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, scrolledwindow4, "scrolledwindow4");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, treeview, "treeview");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, vseparator1, "vseparator1");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, vbox22, "vbox22");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, frame10, "frame10");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, vbox13, "vbox13");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, edit_bt, "edit_bt");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, colors_bt, "colors_bt");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, alignment14, "alignment14");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, hbox41, "hbox41");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, image20, "image20");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, label105, "label105");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, proxy_bt, "proxy_bt");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, remove_bt, "remove_bt");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, alignment13, "alignment13");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, hbox40, "hbox40");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, image19, "image19");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, label_remoev, "label_remoev");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, label103, "label103");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, frame11, "frame11");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, vbox23, "vbox23");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, new_site_bt, "new_site_bt");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, alignment11, "alignment11");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, hbox38, "hbox38");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, image17, "image17");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, label102, "label102");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, pinnipede_settings_bt, "pinnipede_settings_bt");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, alignment12, "alignment12");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, hbox39, "hbox39");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, image18, "image18");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, label_pini, "label_pini");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, edit_options_bt, "edit_options_bt");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, alignment4, "alignment4");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, hbox24, "hbox24");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, image7, "image7");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, label73, "label73");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, label104, "label104");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, hseparator3, "hseparator3");
  GLADE_HOOKUP_OBJECT_NO_REF (sitelist_dialog, dialog_action_area7, "dialog_action_area7");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, cancel_bt, "cancel_bt");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, apply_bt, "apply_bt");
  GLADE_HOOKUP_OBJECT (sitelist_dialog, save_bt, "save_bt");
  GLADE_HOOKUP_OBJECT_NO_REF (sitelist_dialog, tooltips, "tooltips");

  return sitelist_dialog;
}

GtkWidget*
create_pinnipede_site_colors_dialog (void)
{
  GtkWidget *pinnipede_site_colors_dialog;
  GtkWidget *dialog_vbox9;
  GtkWidget *frame8;
  GtkWidget *vbox14;
  GtkWidget *blah;
  GtkWidget *mark_id_gaps;
  GtkWidget *mark_id_gaps_fb;
  GtkWidget *frame9;
  GtkWidget *table4;
  GtkWidget *label43;
  GtkWidget *pp_bgcolor;
  GtkWidget *label44;
  GtkWidget *label45;
  GtkWidget *label46;
  GtkWidget *label47;
  GtkWidget *label48;
  GtkWidget *label49;
  GtkWidget *label50;
  GtkWidget *pp_fgcolor_opaque;
  GtkWidget *pp_trollscore_color_opaque;
  GtkWidget *pp_login_color_opaque;
  GtkWidget *pp_useragent_color_opaque;
  GtkWidget *pp_tstamp_color_opaque;
  GtkWidget *pp_url_color_opaque;
  GtkWidget *pp_visited_url_color_opaque;
  GtkWidget *pp_trollscore_color_transp;
  GtkWidget *pp_useragent_color_transp;
  GtkWidget *pp_tstamp_color_transp;
  GtkWidget *pp_url_color_transp;
  GtkWidget *pp_visited_url_color_transp;
  GtkWidget *pp_login_color_transp;
  GtkWidget *pp_fgcolor_transp;
  GtkWidget *label51;
  GtkWidget *label52;
  GtkWidget *dialog_action_area9;
  GtkWidget *cancelbutton2;
  GtkWidget *apply_bt;
  GtkWidget *okbutton2;

  pinnipede_site_colors_dialog = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (pinnipede_site_colors_dialog), _("Change some colors"));
  gtk_window_set_type_hint (GTK_WINDOW (pinnipede_site_colors_dialog), GDK_WINDOW_TYPE_HINT_DIALOG);

  dialog_vbox9 = GTK_DIALOG (pinnipede_site_colors_dialog)->vbox;
  gtk_widget_show (dialog_vbox9);

  frame8 = gtk_frame_new (NULL);
  gtk_widget_show (frame8);
  gtk_box_pack_start (GTK_BOX (dialog_vbox9), frame8, TRUE, TRUE, 0);

  vbox14 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox14);
  gtk_container_add (GTK_CONTAINER (frame8), vbox14);

  blah = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (blah);
  gtk_box_pack_start (GTK_BOX (vbox14), blah, FALSE, FALSE, 0);

  mark_id_gaps = gtk_check_button_new_with_mnemonic (_("View id gaps (red dotted line)"));
  gtk_widget_show (mark_id_gaps);
  gtk_box_pack_start (GTK_BOX (blah), mark_id_gaps, FALSE, FALSE, 0);

  mark_id_gaps_fb = gtk_label_new (_("xx"));
  gtk_widget_show (mark_id_gaps_fb);
  gtk_box_pack_start (GTK_BOX (blah), mark_id_gaps_fb, FALSE, FALSE, 0);

  frame9 = gtk_frame_new (NULL);
  gtk_widget_show (frame9);
  gtk_box_pack_start (GTK_BOX (vbox14), frame9, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame9), 2);

  table4 = gtk_table_new (3, 9, FALSE);
  gtk_widget_show (table4);
  gtk_container_add (GTK_CONTAINER (frame9), table4);
  gtk_table_set_col_spacings (GTK_TABLE (table4), 5);

  label43 = gtk_label_new (_("Background color"));
  gtk_widget_show (label43);
  gtk_table_attach (GTK_TABLE (table4), label43, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label43), 0, 0.5);

  pp_bgcolor = gtk_button_new_with_mnemonic (_("pp_bgcolor_bt"));
  gtk_widget_show (pp_bgcolor);
  gtk_table_attach (GTK_TABLE (table4), pp_bgcolor, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label44 = gtk_label_new (_("Text foreground"));
  gtk_widget_show (label44);
  gtk_table_attach (GTK_TABLE (table4), label44, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label44), 0, 0.5);

  label45 = gtk_label_new (_("Logins"));
  gtk_widget_show (label45);
  gtk_table_attach (GTK_TABLE (table4), label45, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label45), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label45), 0, 0.5);

  label46 = gtk_label_new (_("Useragents"));
  gtk_widget_show (label46);
  gtk_table_attach (GTK_TABLE (table4), label46, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label46), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label46), 0, 0.5);

  label47 = gtk_label_new (_("Urls"));
  gtk_widget_show (label47);
  gtk_table_attach (GTK_TABLE (table4), label47, 6, 7, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label47), 0, 0.5);

  label48 = gtk_label_new (_("Visited Urls"));
  gtk_widget_show (label48);
  gtk_table_attach (GTK_TABLE (table4), label48, 6, 7, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label48), 0, 0.5);

  label49 = gtk_label_new (_("Clocks"));
  gtk_widget_show (label49);
  gtk_table_attach (GTK_TABLE (table4), label49, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label49), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label49), 0, 0.5);

  label50 = gtk_label_new (_("Troll score"));
  gtk_widget_show (label50);
  gtk_table_attach (GTK_TABLE (table4), label50, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label50), 0, 0.5);

  pp_fgcolor_opaque = gtk_button_new_with_mnemonic (_("button4"));
  gtk_widget_show (pp_fgcolor_opaque);
  gtk_table_attach (GTK_TABLE (table4), pp_fgcolor_opaque, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  pp_trollscore_color_opaque = gtk_button_new_with_mnemonic (_("button5"));
  gtk_widget_show (pp_trollscore_color_opaque);
  gtk_table_attach (GTK_TABLE (table4), pp_trollscore_color_opaque, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  pp_login_color_opaque = gtk_button_new_with_mnemonic (_("button5"));
  gtk_widget_show (pp_login_color_opaque);
  gtk_table_attach (GTK_TABLE (table4), pp_login_color_opaque, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  pp_useragent_color_opaque = gtk_button_new_with_mnemonic (_("button5"));
  gtk_widget_show (pp_useragent_color_opaque);
  gtk_table_attach (GTK_TABLE (table4), pp_useragent_color_opaque, 4, 5, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  pp_tstamp_color_opaque = gtk_button_new_with_mnemonic (_("button5"));
  gtk_widget_show (pp_tstamp_color_opaque);
  gtk_table_attach (GTK_TABLE (table4), pp_tstamp_color_opaque, 4, 5, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  pp_url_color_opaque = gtk_button_new_with_mnemonic (_("button5"));
  gtk_widget_show (pp_url_color_opaque);
  gtk_table_attach (GTK_TABLE (table4), pp_url_color_opaque, 7, 8, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  pp_visited_url_color_opaque = gtk_button_new_with_mnemonic (_("button5"));
  gtk_widget_show (pp_visited_url_color_opaque);
  gtk_table_attach (GTK_TABLE (table4), pp_visited_url_color_opaque, 7, 8, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  pp_trollscore_color_transp = gtk_button_new_with_mnemonic (_("button4"));
  gtk_widget_show (pp_trollscore_color_transp);
  gtk_table_attach (GTK_TABLE (table4), pp_trollscore_color_transp, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  pp_useragent_color_transp = gtk_button_new_with_mnemonic (_("button4"));
  gtk_widget_show (pp_useragent_color_transp);
  gtk_table_attach (GTK_TABLE (table4), pp_useragent_color_transp, 5, 6, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  pp_tstamp_color_transp = gtk_button_new_with_mnemonic (_("button4"));
  gtk_widget_show (pp_tstamp_color_transp);
  gtk_table_attach (GTK_TABLE (table4), pp_tstamp_color_transp, 5, 6, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  pp_url_color_transp = gtk_button_new_with_mnemonic (_("button4"));
  gtk_widget_show (pp_url_color_transp);
  gtk_table_attach (GTK_TABLE (table4), pp_url_color_transp, 8, 9, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  pp_visited_url_color_transp = gtk_button_new_with_mnemonic (_("button4"));
  gtk_widget_show (pp_visited_url_color_transp);
  gtk_table_attach (GTK_TABLE (table4), pp_visited_url_color_transp, 8, 9, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  pp_login_color_transp = gtk_button_new_with_mnemonic (_("button4"));
  gtk_widget_show (pp_login_color_transp);
  gtk_table_attach (GTK_TABLE (table4), pp_login_color_transp, 5, 6, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  pp_fgcolor_transp = gtk_button_new_with_mnemonic (_("button4"));
  gtk_widget_show (pp_fgcolor_transp);
  gtk_table_attach (GTK_TABLE (table4), pp_fgcolor_transp, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label51 = gtk_label_new (_("Various colors"));
  gtk_widget_show (label51);
  gtk_frame_set_label_widget (GTK_FRAME (frame9), label51);

  label52 = gtk_label_new (_("Visual settings applied to selected sites"));
  gtk_widget_show (label52);
  gtk_frame_set_label_widget (GTK_FRAME (frame8), label52);

  dialog_action_area9 = GTK_DIALOG (pinnipede_site_colors_dialog)->action_area;
  gtk_widget_show (dialog_action_area9);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area9), GTK_BUTTONBOX_END);

  cancelbutton2 = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (cancelbutton2);
  gtk_dialog_add_action_widget (GTK_DIALOG (pinnipede_site_colors_dialog), cancelbutton2, GTK_RESPONSE_CANCEL);
  GTK_WIDGET_SET_FLAGS (cancelbutton2, GTK_CAN_DEFAULT);

  apply_bt = gtk_button_new_from_stock ("gtk-apply");
  gtk_widget_show (apply_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (pinnipede_site_colors_dialog), apply_bt, GTK_RESPONSE_APPLY);
  GTK_WIDGET_SET_FLAGS (apply_bt, GTK_CAN_DEFAULT);

  okbutton2 = gtk_button_new_from_stock ("gtk-ok");
  gtk_widget_show (okbutton2);
  gtk_dialog_add_action_widget (GTK_DIALOG (pinnipede_site_colors_dialog), okbutton2, GTK_RESPONSE_OK);
  GTK_WIDGET_SET_FLAGS (okbutton2, GTK_CAN_DEFAULT);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (pinnipede_site_colors_dialog, pinnipede_site_colors_dialog, "pinnipede_site_colors_dialog");
  GLADE_HOOKUP_OBJECT_NO_REF (pinnipede_site_colors_dialog, dialog_vbox9, "dialog_vbox9");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, frame8, "frame8");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, vbox14, "vbox14");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, blah, "blah");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, mark_id_gaps, "mark_id_gaps");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, mark_id_gaps_fb, "mark_id_gaps_fb");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, frame9, "frame9");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, table4, "table4");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, label43, "label43");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, pp_bgcolor, "pp_bgcolor");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, label44, "label44");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, label45, "label45");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, label46, "label46");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, label47, "label47");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, label48, "label48");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, label49, "label49");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, label50, "label50");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, pp_fgcolor_opaque, "pp_fgcolor_opaque");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, pp_trollscore_color_opaque, "pp_trollscore_color_opaque");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, pp_login_color_opaque, "pp_login_color_opaque");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, pp_useragent_color_opaque, "pp_useragent_color_opaque");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, pp_tstamp_color_opaque, "pp_tstamp_color_opaque");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, pp_url_color_opaque, "pp_url_color_opaque");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, pp_visited_url_color_opaque, "pp_visited_url_color_opaque");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, pp_trollscore_color_transp, "pp_trollscore_color_transp");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, pp_useragent_color_transp, "pp_useragent_color_transp");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, pp_tstamp_color_transp, "pp_tstamp_color_transp");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, pp_url_color_transp, "pp_url_color_transp");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, pp_visited_url_color_transp, "pp_visited_url_color_transp");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, pp_login_color_transp, "pp_login_color_transp");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, pp_fgcolor_transp, "pp_fgcolor_transp");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, label51, "label51");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, label52, "label52");
  GLADE_HOOKUP_OBJECT_NO_REF (pinnipede_site_colors_dialog, dialog_action_area9, "dialog_action_area9");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, cancelbutton2, "cancelbutton2");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, apply_bt, "apply_bt");
  GLADE_HOOKUP_OBJECT (pinnipede_site_colors_dialog, okbutton2, "okbutton2");

  return pinnipede_site_colors_dialog;
}

GtkWidget*
create_change_board_settings_dialog (void)
{
  GtkWidget *change_board_settings_dialog;
  GtkWidget *dialog_vbox10;
  GtkWidget *table5;
  GtkWidget *label55;
  GtkWidget *hbox20;
  GtkWidget *all_names_0_;
  GtkWidget *all_names_1_;
  GtkWidget *all_names_2_;
  GtkWidget *all_names_3_;
  GtkWidget *label57;
  GtkWidget *label58;
  GtkWidget *hbox21;
  GtkObject *board_check_delay_adj;
  GtkWidget *board_check_delay;
  GtkWidget *label59;
  GtkWidget *board_check_delay_fb;
  GtkWidget *backend_url;
  GtkWidget *post_url;
  GtkWidget *user_cookie;
  GtkWidget *label66;
  GtkWidget *label67;
  GtkWidget *backend_flavour;
  GtkWidget *menu2;
  GtkWidget *menuitem5;
  GtkWidget *menuitem6;
  GtkWidget *menuitem7;
  GtkWidget *hbox22;
  GtkWidget *label60;
  GtkWidget *grab_cookie_bt;
  GtkWidget *alignment10;
  GtkWidget *hbox30;
  GtkWidget *image13;
  GtkWidget *label79;
  GtkWidget *post_template;
  GtkWidget *label68;
  GtkWidget *label70;
  GtkWidget *user_login;
  GtkWidget *label86;
  GtkWidget *user_agent;
  GtkWidget *hunt_opened_on_site;
  GtkWidget *dialog_action_area10;
  GtkWidget *cancelbutton3;
  GtkWidget *apply_bt;
  GtkWidget *okbutton3;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  change_board_settings_dialog = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (change_board_settings_dialog), _("Change board settings"));
  gtk_window_set_type_hint (GTK_WINDOW (change_board_settings_dialog), GDK_WINDOW_TYPE_HINT_DIALOG);

  dialog_vbox10 = GTK_DIALOG (change_board_settings_dialog)->vbox;
  gtk_widget_show (dialog_vbox10);

  table5 = gtk_table_new (10, 2, FALSE);
  gtk_widget_show (table5);
  gtk_box_pack_start (GTK_BOX (dialog_vbox10), table5, TRUE, TRUE, 0);

  label55 = gtk_label_new (_("Site name, and aliases:"));
  gtk_widget_show (label55);
  gtk_table_attach (GTK_TABLE (table5), label55, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label55), 0, 0.5);

  hbox20 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox20);
  gtk_table_attach (GTK_TABLE (table5), hbox20, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  all_names_0_ = gtk_entry_new ();
  gtk_widget_show (all_names_0_);
  gtk_box_pack_start (GTK_BOX (hbox20), all_names_0_, FALSE, TRUE, 0);

  all_names_1_ = gtk_entry_new ();
  gtk_widget_show (all_names_1_);
  gtk_box_pack_start (GTK_BOX (hbox20), all_names_1_, FALSE, TRUE, 0);
  gtk_widget_set_size_request (all_names_1_, 120, -1);

  all_names_2_ = gtk_entry_new ();
  gtk_widget_show (all_names_2_);
  gtk_box_pack_start (GTK_BOX (hbox20), all_names_2_, FALSE, FALSE, 0);
  gtk_widget_set_size_request (all_names_2_, 120, -1);

  all_names_3_ = gtk_entry_new ();
  gtk_widget_show (all_names_3_);
  gtk_box_pack_start (GTK_BOX (hbox20), all_names_3_, FALSE, TRUE, 0);
  gtk_widget_set_size_request (all_names_3_, 120, -1);

  label57 = gtk_label_new (_("Post URL:"));
  gtk_widget_show (label57);
  gtk_table_attach (GTK_TABLE (table5), label57, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label57), 0, 0.5);

  label58 = gtk_label_new (_("Refresh frequency:"));
  gtk_widget_show (label58);
  gtk_table_attach (GTK_TABLE (table5), label58, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label58), 0, 0.5);

  hbox21 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox21);
  gtk_table_attach (GTK_TABLE (table5), hbox21, 1, 2, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  board_check_delay_adj = gtk_adjustment_new (100, 10, 10000, 1, 10, 10);
  board_check_delay = gtk_spin_button_new (GTK_ADJUSTMENT (board_check_delay_adj), 1, 0);
  gtk_widget_show (board_check_delay);
  gtk_box_pack_start (GTK_BOX (hbox21), board_check_delay, FALSE, TRUE, 0);

  label59 = gtk_label_new (_("seconds  "));
  gtk_widget_show (label59);
  gtk_box_pack_start (GTK_BOX (hbox21), label59, FALSE, FALSE, 0);

  board_check_delay_fb = gtk_label_new (_("  "));
  gtk_widget_show (board_check_delay_fb);
  gtk_box_pack_start (GTK_BOX (hbox21), board_check_delay_fb, FALSE, FALSE, 0);

  backend_url = gtk_entry_new ();
  gtk_widget_show (backend_url);
  gtk_table_attach (GTK_TABLE (table5), backend_url, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  post_url = gtk_entry_new ();
  gtk_widget_show (post_url);
  gtk_table_attach (GTK_TABLE (table5), post_url, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  user_cookie = gtk_entry_new ();
  gtk_widget_show (user_cookie);
  gtk_table_attach (GTK_TABLE (table5), user_cookie, 1, 2, 6, 7,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label66 = gtk_label_new (_("Backend URL:"));
  gtk_widget_show (label66);
  gtk_table_attach (GTK_TABLE (table5), label66, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label66), 0, 0.5);

  label67 = gtk_label_new (_("Backend flavour:"));
  gtk_widget_show (label67);
  gtk_table_attach (GTK_TABLE (table5), label67, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label67), 0, 0.5);

  backend_flavour = gtk_option_menu_new ();
  gtk_widget_show (backend_flavour);
  gtk_table_attach (GTK_TABLE (table5), backend_flavour, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  menu2 = gtk_menu_new ();

  menuitem5 = gtk_menu_item_new_with_mnemonic (_("message tags are \"htmlentitised\""));
  gtk_widget_show (menuitem5);
  gtk_container_add (GTK_CONTAINER (menu2), menuitem5);

  menuitem6 = gtk_menu_item_new_with_mnemonic (_("message tags are raw"));
  gtk_widget_show (menuitem6);
  gtk_container_add (GTK_CONTAINER (menu2), menuitem6);

  menuitem7 = gtk_menu_item_new_with_mnemonic (_("the backend has no pants"));
  gtk_widget_show (menuitem7);
  gtk_container_add (GTK_CONTAINER (menu2), menuitem7);

  gtk_option_menu_set_menu (GTK_OPTION_MENU (backend_flavour), menu2);

  hbox22 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox22);
  gtk_table_attach (GTK_TABLE (table5), hbox22, 0, 1, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label60 = gtk_label_new (_("Cookie(s)"));
  gtk_widget_show (label60);
  gtk_box_pack_start (GTK_BOX (hbox22), label60, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label60), 0, 0.5);

  grab_cookie_bt = gtk_button_new ();
  gtk_widget_show (grab_cookie_bt);
  gtk_box_pack_start (GTK_BOX (hbox22), grab_cookie_bt, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, grab_cookie_bt, _("attempt to get the cookie from the cookies stored in your browsers"), NULL);

  alignment10 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment10);
  gtk_container_add (GTK_CONTAINER (grab_cookie_bt), alignment10);

  hbox30 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox30);
  gtk_container_add (GTK_CONTAINER (alignment10), hbox30);

  image13 = gtk_image_new_from_stock ("gtk-find", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image13);
  gtk_box_pack_start (GTK_BOX (hbox30), image13, FALSE, FALSE, 0);

  label79 = gtk_label_new_with_mnemonic (_("(grab cookie)"));
  gtk_widget_show (label79);
  gtk_box_pack_start (GTK_BOX (hbox30), label79, FALSE, FALSE, 0);

  post_template = gtk_entry_new ();
  gtk_widget_show (post_template);
  gtk_table_attach (GTK_TABLE (table5), post_template, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label68 = gtk_label_new (_("Post Template:"));
  gtk_widget_show (label68);
  gtk_table_attach (GTK_TABLE (table5), label68, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label68), 0, 0.5);

  label70 = gtk_label_new (_("Optional login:"));
  gtk_widget_show (label70);
  gtk_table_attach (GTK_TABLE (table5), label70, 0, 1, 7, 8,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label70), 0, 0.5);

  user_login = gtk_entry_new ();
  gtk_widget_show (user_login);
  gtk_table_attach (GTK_TABLE (table5), user_login, 1, 2, 7, 8,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label86 = gtk_label_new (_("Default useragent:"));
  gtk_widget_show (label86);
  gtk_table_attach (GTK_TABLE (table5), label86, 0, 1, 8, 9,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label86), 0, 0.5);

  user_agent = gtk_entry_new ();
  gtk_widget_show (user_agent);
  gtk_table_attach (GTK_TABLE (table5), user_agent, 1, 2, 8, 9,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, user_agent, _("$v will be replaced by the wmcoincoin version, and $s, $r, $m will be replaced by the output of the command uname -a"), NULL);

  hunt_opened_on_site = gtk_check_button_new_with_mnemonic (_("balltrap is allowed on this board"));
  gtk_widget_show (hunt_opened_on_site);
  gtk_table_attach (GTK_TABLE (table5), hunt_opened_on_site, 1, 2, 9, 10,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, hunt_opened_on_site, _("you can enable/disable the balltrap for each site. Note that there is also a global switch for the balltrap in the pinnipede button bar."), NULL);

  dialog_action_area10 = GTK_DIALOG (change_board_settings_dialog)->action_area;
  gtk_widget_show (dialog_action_area10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area10), GTK_BUTTONBOX_END);

  cancelbutton3 = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (cancelbutton3);
  gtk_dialog_add_action_widget (GTK_DIALOG (change_board_settings_dialog), cancelbutton3, GTK_RESPONSE_CANCEL);
  GTK_WIDGET_SET_FLAGS (cancelbutton3, GTK_CAN_DEFAULT);

  apply_bt = gtk_button_new_from_stock ("gtk-apply");
  gtk_widget_show (apply_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (change_board_settings_dialog), apply_bt, GTK_RESPONSE_APPLY);
  GTK_WIDGET_SET_FLAGS (apply_bt, GTK_CAN_DEFAULT);

  okbutton3 = gtk_button_new_from_stock ("gtk-ok");
  gtk_widget_show (okbutton3);
  gtk_dialog_add_action_widget (GTK_DIALOG (change_board_settings_dialog), okbutton3, GTK_RESPONSE_OK);
  GTK_WIDGET_SET_FLAGS (okbutton3, GTK_CAN_DEFAULT);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (change_board_settings_dialog, change_board_settings_dialog, "change_board_settings_dialog");
  GLADE_HOOKUP_OBJECT_NO_REF (change_board_settings_dialog, dialog_vbox10, "dialog_vbox10");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, table5, "table5");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, label55, "label55");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, hbox20, "hbox20");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, all_names_0_, "all_names_0_");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, all_names_1_, "all_names_1_");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, all_names_2_, "all_names_2_");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, all_names_3_, "all_names_3_");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, label57, "label57");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, label58, "label58");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, hbox21, "hbox21");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, board_check_delay, "board_check_delay");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, label59, "label59");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, board_check_delay_fb, "board_check_delay_fb");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, backend_url, "backend_url");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, post_url, "post_url");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, user_cookie, "user_cookie");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, label66, "label66");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, label67, "label67");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, backend_flavour, "backend_flavour");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, menu2, "menu2");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, menuitem5, "menuitem5");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, menuitem6, "menuitem6");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, menuitem7, "menuitem7");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, hbox22, "hbox22");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, label60, "label60");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, grab_cookie_bt, "grab_cookie_bt");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, alignment10, "alignment10");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, hbox30, "hbox30");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, image13, "image13");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, label79, "label79");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, post_template, "post_template");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, label68, "label68");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, label70, "label70");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, user_login, "user_login");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, label86, "label86");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, user_agent, "user_agent");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, hunt_opened_on_site, "hunt_opened_on_site");
  GLADE_HOOKUP_OBJECT_NO_REF (change_board_settings_dialog, dialog_action_area10, "dialog_action_area10");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, cancelbutton3, "cancelbutton3");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, apply_bt, "apply_bt");
  GLADE_HOOKUP_OBJECT (change_board_settings_dialog, okbutton3, "okbutton3");
  GLADE_HOOKUP_OBJECT_NO_REF (change_board_settings_dialog, tooltips, "tooltips");

  return change_board_settings_dialog;
}

GtkWidget*
create_change_rss_settings_dialog (void)
{
  GtkWidget *change_rss_settings_dialog;
  GtkWidget *dialog_vbox10;
  GtkWidget *table5;
  GtkWidget *label55;
  GtkWidget *hbox20;
  GtkWidget *all_names_0_;
  GtkWidget *all_names_1_;
  GtkWidget *all_names_2_;
  GtkWidget *all_names_3_;
  GtkWidget *label58;
  GtkWidget *hbox21;
  GtkObject *board_check_delay_adj;
  GtkWidget *board_check_delay;
  GtkWidget *label59;
  GtkWidget *board_check_delay_fb;
  GtkWidget *backend_url;
  GtkWidget *user_cookie;
  GtkWidget *label66;
  GtkWidget *label67;
  GtkWidget *backend_flavour;
  GtkWidget *menu2;
  GtkWidget *menuitem5;
  GtkWidget *menuitem6;
  GtkWidget *menuitem7;
  GtkWidget *hbox22;
  GtkWidget *label60;
  GtkWidget *grab_cookie_bt;
  GtkWidget *rss_ignore_description;
  GtkWidget *dialog_action_area10;
  GtkWidget *cancelbutton3;
  GtkWidget *apply_bt;
  GtkWidget *okbutton3;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  change_rss_settings_dialog = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (change_rss_settings_dialog), _("Change RSS Feed settings"));
  gtk_window_set_type_hint (GTK_WINDOW (change_rss_settings_dialog), GDK_WINDOW_TYPE_HINT_DIALOG);

  dialog_vbox10 = GTK_DIALOG (change_rss_settings_dialog)->vbox;
  gtk_widget_show (dialog_vbox10);

  table5 = gtk_table_new (9, 2, FALSE);
  gtk_widget_show (table5);
  gtk_box_pack_start (GTK_BOX (dialog_vbox10), table5, TRUE, TRUE, 0);

  label55 = gtk_label_new (_("Site name, and aliases:"));
  gtk_widget_show (label55);
  gtk_table_attach (GTK_TABLE (table5), label55, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label55), 0, 0.5);

  hbox20 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox20);
  gtk_table_attach (GTK_TABLE (table5), hbox20, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  all_names_0_ = gtk_entry_new ();
  gtk_widget_show (all_names_0_);
  gtk_box_pack_start (GTK_BOX (hbox20), all_names_0_, FALSE, TRUE, 0);
  gtk_widget_set_size_request (all_names_0_, 158, -1);

  all_names_1_ = gtk_entry_new ();
  gtk_widget_show (all_names_1_);
  gtk_box_pack_start (GTK_BOX (hbox20), all_names_1_, FALSE, TRUE, 0);
  gtk_widget_set_size_request (all_names_1_, 120, -1);

  all_names_2_ = gtk_entry_new ();
  gtk_widget_show (all_names_2_);
  gtk_box_pack_start (GTK_BOX (hbox20), all_names_2_, FALSE, FALSE, 0);
  gtk_widget_set_size_request (all_names_2_, 120, -1);

  all_names_3_ = gtk_entry_new ();
  gtk_widget_show (all_names_3_);
  gtk_box_pack_start (GTK_BOX (hbox20), all_names_3_, FALSE, TRUE, 0);
  gtk_widget_set_size_request (all_names_3_, 120, -1);

  label58 = gtk_label_new (_("Refresh frequency:"));
  gtk_widget_show (label58);
  gtk_table_attach (GTK_TABLE (table5), label58, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label58), 0, 0.5);

  hbox21 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox21);
  gtk_table_attach (GTK_TABLE (table5), hbox21, 1, 2, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  board_check_delay_adj = gtk_adjustment_new (1, 1, 10000, 1, 10, 10);
  board_check_delay = gtk_spin_button_new (GTK_ADJUSTMENT (board_check_delay_adj), 1, 0);
  gtk_widget_show (board_check_delay);
  gtk_box_pack_start (GTK_BOX (hbox21), board_check_delay, FALSE, TRUE, 0);

  label59 = gtk_label_new (_("seconds  "));
  gtk_widget_show (label59);
  gtk_box_pack_start (GTK_BOX (hbox21), label59, FALSE, FALSE, 0);

  board_check_delay_fb = gtk_label_new (_("  "));
  gtk_widget_show (board_check_delay_fb);
  gtk_box_pack_start (GTK_BOX (hbox21), board_check_delay_fb, FALSE, FALSE, 0);

  backend_url = gtk_entry_new ();
  gtk_widget_show (backend_url);
  gtk_table_attach (GTK_TABLE (table5), backend_url, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  user_cookie = gtk_entry_new ();
  gtk_widget_show (user_cookie);
  gtk_table_attach (GTK_TABLE (table5), user_cookie, 1, 2, 6, 7,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label66 = gtk_label_new (_("Backend URL:"));
  gtk_widget_show (label66);
  gtk_table_attach (GTK_TABLE (table5), label66, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label66), 0, 0.5);

  label67 = gtk_label_new (_("Backend flavour:"));
  gtk_widget_show (label67);
  gtk_table_attach (GTK_TABLE (table5), label67, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label67), 0, 0.5);

  backend_flavour = gtk_option_menu_new ();
  gtk_widget_show (backend_flavour);
  gtk_table_attach (GTK_TABLE (table5), backend_flavour, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  menu2 = gtk_menu_new ();

  menuitem5 = gtk_menu_item_new_with_mnemonic (_("message tags are \"htmlentitised\""));
  gtk_widget_show (menuitem5);
  gtk_container_add (GTK_CONTAINER (menu2), menuitem5);

  menuitem6 = gtk_menu_item_new_with_mnemonic (_("message tags are raw"));
  gtk_widget_show (menuitem6);
  gtk_container_add (GTK_CONTAINER (menu2), menuitem6);

  menuitem7 = gtk_menu_item_new_with_mnemonic (_("the backend has no pants"));
  gtk_widget_show (menuitem7);
  gtk_container_add (GTK_CONTAINER (menu2), menuitem7);

  gtk_option_menu_set_menu (GTK_OPTION_MENU (backend_flavour), menu2);

  hbox22 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox22);
  gtk_table_attach (GTK_TABLE (table5), hbox22, 0, 1, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label60 = gtk_label_new (_("Cookie(s)"));
  gtk_widget_show (label60);
  gtk_box_pack_start (GTK_BOX (hbox22), label60, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label60), 0, 0.5);

  grab_cookie_bt = gtk_button_new_with_mnemonic (_("(grab cookie)"));
  gtk_widget_show (grab_cookie_bt);
  gtk_box_pack_start (GTK_BOX (hbox22), grab_cookie_bt, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, grab_cookie_bt, _("attempt to get the cookie from the cookies stored in your browsers"), NULL);

  rss_ignore_description = gtk_check_button_new_with_mnemonic (_("Ignore <description> content (some links-only feeds contain ads in this field)"));
  gtk_widget_show (rss_ignore_description);
  gtk_table_attach (GTK_TABLE (table5), rss_ignore_description, 0, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  dialog_action_area10 = GTK_DIALOG (change_rss_settings_dialog)->action_area;
  gtk_widget_show (dialog_action_area10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area10), GTK_BUTTONBOX_END);

  cancelbutton3 = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (cancelbutton3);
  gtk_dialog_add_action_widget (GTK_DIALOG (change_rss_settings_dialog), cancelbutton3, GTK_RESPONSE_CANCEL);
  GTK_WIDGET_SET_FLAGS (cancelbutton3, GTK_CAN_DEFAULT);

  apply_bt = gtk_button_new_from_stock ("gtk-apply");
  gtk_widget_show (apply_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (change_rss_settings_dialog), apply_bt, GTK_RESPONSE_APPLY);
  GTK_WIDGET_SET_FLAGS (apply_bt, GTK_CAN_DEFAULT);

  okbutton3 = gtk_button_new_from_stock ("gtk-ok");
  gtk_widget_show (okbutton3);
  gtk_dialog_add_action_widget (GTK_DIALOG (change_rss_settings_dialog), okbutton3, GTK_RESPONSE_OK);
  GTK_WIDGET_SET_FLAGS (okbutton3, GTK_CAN_DEFAULT);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (change_rss_settings_dialog, change_rss_settings_dialog, "change_rss_settings_dialog");
  GLADE_HOOKUP_OBJECT_NO_REF (change_rss_settings_dialog, dialog_vbox10, "dialog_vbox10");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, table5, "table5");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, label55, "label55");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, hbox20, "hbox20");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, all_names_0_, "all_names_0_");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, all_names_1_, "all_names_1_");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, all_names_2_, "all_names_2_");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, all_names_3_, "all_names_3_");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, label58, "label58");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, hbox21, "hbox21");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, board_check_delay, "board_check_delay");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, label59, "label59");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, board_check_delay_fb, "board_check_delay_fb");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, backend_url, "backend_url");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, user_cookie, "user_cookie");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, label66, "label66");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, label67, "label67");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, backend_flavour, "backend_flavour");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, menu2, "menu2");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, menuitem5, "menuitem5");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, menuitem6, "menuitem6");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, menuitem7, "menuitem7");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, hbox22, "hbox22");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, label60, "label60");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, grab_cookie_bt, "grab_cookie_bt");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, rss_ignore_description, "rss_ignore_description");
  GLADE_HOOKUP_OBJECT_NO_REF (change_rss_settings_dialog, dialog_action_area10, "dialog_action_area10");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, cancelbutton3, "cancelbutton3");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, apply_bt, "apply_bt");
  GLADE_HOOKUP_OBJECT (change_rss_settings_dialog, okbutton3, "okbutton3");
  GLADE_HOOKUP_OBJECT_NO_REF (change_rss_settings_dialog, tooltips, "tooltips");

  return change_rss_settings_dialog;
}

GtkWidget*
create_change_pop_settings_dialog (void)
{
  GtkWidget *change_pop_settings_dialog;
  GtkWidget *dialog_vbox10;
  GtkWidget *table5;
  GtkWidget *label55;
  GtkWidget *hbox20;
  GtkWidget *all_names_0_;
  GtkWidget *all_names_1_;
  GtkWidget *all_names_2_;
  GtkWidget *all_names_3_;
  GtkWidget *label58;
  GtkWidget *hbox21;
  GtkObject *board_check_delay_adj;
  GtkWidget *board_check_delay;
  GtkWidget *label59;
  GtkWidget *board_check_delay_fb;
  GtkWidget *backend_url;
  GtkWidget *label66;
  GtkWidget *label68;
  GtkWidget *pop3_user;
  GtkWidget *label69;
  GtkWidget *pop3_pass;
  GtkWidget *dialog_action_area10;
  GtkWidget *cancelbutton3;
  GtkWidget *apply_bt;
  GtkWidget *okbutton3;

  change_pop_settings_dialog = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (change_pop_settings_dialog), _("Change POP account settings"));
  gtk_window_set_type_hint (GTK_WINDOW (change_pop_settings_dialog), GDK_WINDOW_TYPE_HINT_DIALOG);

  dialog_vbox10 = GTK_DIALOG (change_pop_settings_dialog)->vbox;
  gtk_widget_show (dialog_vbox10);

  table5 = gtk_table_new (9, 2, FALSE);
  gtk_widget_show (table5);
  gtk_box_pack_start (GTK_BOX (dialog_vbox10), table5, TRUE, TRUE, 0);

  label55 = gtk_label_new (_("Site name, and aliases:"));
  gtk_widget_show (label55);
  gtk_table_attach (GTK_TABLE (table5), label55, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label55), 0, 0.5);

  hbox20 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox20);
  gtk_table_attach (GTK_TABLE (table5), hbox20, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  all_names_0_ = gtk_entry_new ();
  gtk_widget_show (all_names_0_);
  gtk_box_pack_start (GTK_BOX (hbox20), all_names_0_, FALSE, TRUE, 0);

  all_names_1_ = gtk_entry_new ();
  gtk_widget_show (all_names_1_);
  gtk_box_pack_start (GTK_BOX (hbox20), all_names_1_, FALSE, TRUE, 0);
  gtk_widget_set_size_request (all_names_1_, 120, -1);

  all_names_2_ = gtk_entry_new ();
  gtk_widget_show (all_names_2_);
  gtk_box_pack_start (GTK_BOX (hbox20), all_names_2_, FALSE, FALSE, 0);
  gtk_widget_set_size_request (all_names_2_, 120, -1);

  all_names_3_ = gtk_entry_new ();
  gtk_widget_show (all_names_3_);
  gtk_box_pack_start (GTK_BOX (hbox20), all_names_3_, FALSE, TRUE, 0);
  gtk_widget_set_size_request (all_names_3_, 120, -1);

  label58 = gtk_label_new (_("Refresh frequency:"));
  gtk_widget_show (label58);
  gtk_table_attach (GTK_TABLE (table5), label58, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label58), 0, 0.5);

  hbox21 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox21);
  gtk_table_attach (GTK_TABLE (table5), hbox21, 1, 2, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  board_check_delay_adj = gtk_adjustment_new (1, 1, 10000, 1, 10, 10);
  board_check_delay = gtk_spin_button_new (GTK_ADJUSTMENT (board_check_delay_adj), 1, 0);
  gtk_widget_show (board_check_delay);
  gtk_box_pack_start (GTK_BOX (hbox21), board_check_delay, FALSE, TRUE, 0);

  label59 = gtk_label_new (_("seconds  "));
  gtk_widget_show (label59);
  gtk_box_pack_start (GTK_BOX (hbox21), label59, FALSE, FALSE, 0);

  board_check_delay_fb = gtk_label_new (_("  "));
  gtk_widget_show (board_check_delay_fb);
  gtk_box_pack_start (GTK_BOX (hbox21), board_check_delay_fb, FALSE, FALSE, 0);

  backend_url = gtk_entry_new ();
  gtk_widget_show (backend_url);
  gtk_table_attach (GTK_TABLE (table5), backend_url, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label66 = gtk_label_new (_("Pop3 server:"));
  gtk_widget_show (label66);
  gtk_table_attach (GTK_TABLE (table5), label66, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label66), 0, 0.5);

  label68 = gtk_label_new (_("Login"));
  gtk_widget_show (label68);
  gtk_table_attach (GTK_TABLE (table5), label68, 0, 1, 7, 8,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label68), 0, 0.5);

  pop3_user = gtk_entry_new ();
  gtk_widget_show (pop3_user);
  gtk_table_attach (GTK_TABLE (table5), pop3_user, 1, 2, 7, 8,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label69 = gtk_label_new (_("Password"));
  gtk_widget_show (label69);
  gtk_table_attach (GTK_TABLE (table5), label69, 0, 1, 8, 9,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label69), 0, 0.5);

  pop3_pass = gtk_entry_new ();
  gtk_widget_show (pop3_pass);
  gtk_table_attach (GTK_TABLE (table5), pop3_pass, 1, 2, 8, 9,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_visibility (GTK_ENTRY (pop3_pass), FALSE);

  dialog_action_area10 = GTK_DIALOG (change_pop_settings_dialog)->action_area;
  gtk_widget_show (dialog_action_area10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area10), GTK_BUTTONBOX_END);

  cancelbutton3 = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (cancelbutton3);
  gtk_dialog_add_action_widget (GTK_DIALOG (change_pop_settings_dialog), cancelbutton3, GTK_RESPONSE_CANCEL);
  GTK_WIDGET_SET_FLAGS (cancelbutton3, GTK_CAN_DEFAULT);

  apply_bt = gtk_button_new_from_stock ("gtk-apply");
  gtk_widget_show (apply_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (change_pop_settings_dialog), apply_bt, GTK_RESPONSE_APPLY);
  GTK_WIDGET_SET_FLAGS (apply_bt, GTK_CAN_DEFAULT);

  okbutton3 = gtk_button_new_from_stock ("gtk-ok");
  gtk_widget_show (okbutton3);
  gtk_dialog_add_action_widget (GTK_DIALOG (change_pop_settings_dialog), okbutton3, GTK_RESPONSE_OK);
  GTK_WIDGET_SET_FLAGS (okbutton3, GTK_CAN_DEFAULT);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (change_pop_settings_dialog, change_pop_settings_dialog, "change_pop_settings_dialog");
  GLADE_HOOKUP_OBJECT_NO_REF (change_pop_settings_dialog, dialog_vbox10, "dialog_vbox10");
  GLADE_HOOKUP_OBJECT (change_pop_settings_dialog, table5, "table5");
  GLADE_HOOKUP_OBJECT (change_pop_settings_dialog, label55, "label55");
  GLADE_HOOKUP_OBJECT (change_pop_settings_dialog, hbox20, "hbox20");
  GLADE_HOOKUP_OBJECT (change_pop_settings_dialog, all_names_0_, "all_names_0_");
  GLADE_HOOKUP_OBJECT (change_pop_settings_dialog, all_names_1_, "all_names_1_");
  GLADE_HOOKUP_OBJECT (change_pop_settings_dialog, all_names_2_, "all_names_2_");
  GLADE_HOOKUP_OBJECT (change_pop_settings_dialog, all_names_3_, "all_names_3_");
  GLADE_HOOKUP_OBJECT (change_pop_settings_dialog, label58, "label58");
  GLADE_HOOKUP_OBJECT (change_pop_settings_dialog, hbox21, "hbox21");
  GLADE_HOOKUP_OBJECT (change_pop_settings_dialog, board_check_delay, "board_check_delay");
  GLADE_HOOKUP_OBJECT (change_pop_settings_dialog, label59, "label59");
  GLADE_HOOKUP_OBJECT (change_pop_settings_dialog, board_check_delay_fb, "board_check_delay_fb");
  GLADE_HOOKUP_OBJECT (change_pop_settings_dialog, backend_url, "backend_url");
  GLADE_HOOKUP_OBJECT (change_pop_settings_dialog, label66, "label66");
  GLADE_HOOKUP_OBJECT (change_pop_settings_dialog, label68, "label68");
  GLADE_HOOKUP_OBJECT (change_pop_settings_dialog, pop3_user, "pop3_user");
  GLADE_HOOKUP_OBJECT (change_pop_settings_dialog, label69, "label69");
  GLADE_HOOKUP_OBJECT (change_pop_settings_dialog, pop3_pass, "pop3_pass");
  GLADE_HOOKUP_OBJECT_NO_REF (change_pop_settings_dialog, dialog_action_area10, "dialog_action_area10");
  GLADE_HOOKUP_OBJECT (change_pop_settings_dialog, cancelbutton3, "cancelbutton3");
  GLADE_HOOKUP_OBJECT (change_pop_settings_dialog, apply_bt, "apply_bt");
  GLADE_HOOKUP_OBJECT (change_pop_settings_dialog, okbutton3, "okbutton3");

  return change_pop_settings_dialog;
}

GtkWidget*
create_grab_cookie_dialog (void)
{
  GtkWidget *grab_cookie_dialog;
  GtkWidget *dialog_vbox11;
  GtkWidget *vbox15;
  GtkWidget *label61;
  GtkWidget *hseparator4;
  GtkWidget *scrolledwindow6;
  GtkWidget *cookies;
  GtkWidget *dialog_action_area11;
  GtkWidget *close_bt;

  grab_cookie_dialog = gtk_dialog_new ();
  gtk_widget_set_size_request (grab_cookie_dialog, 786, 470);
  gtk_window_set_title (GTK_WINDOW (grab_cookie_dialog), _("grab a cookie from your browsers"));
  gtk_window_set_type_hint (GTK_WINDOW (grab_cookie_dialog), GDK_WINDOW_TYPE_HINT_DIALOG);

  dialog_vbox11 = GTK_DIALOG (grab_cookie_dialog)->vbox;
  gtk_widget_show (dialog_vbox11);

  vbox15 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox15);
  gtk_box_pack_start (GTK_BOX (dialog_vbox11), vbox15, TRUE, TRUE, 0);

  label61 = gtk_label_new (_("Cut and paste the selected cookies."));
  gtk_widget_show (label61);
  gtk_box_pack_start (GTK_BOX (vbox15), label61, FALSE, FALSE, 0);

  hseparator4 = gtk_hseparator_new ();
  gtk_widget_show (hseparator4);
  gtk_box_pack_start (GTK_BOX (vbox15), hseparator4, FALSE, FALSE, 0);

  scrolledwindow6 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow6);
  gtk_box_pack_start (GTK_BOX (vbox15), scrolledwindow6, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow6), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  cookies = gtk_text_view_new ();
  gtk_widget_show (cookies);
  gtk_container_add (GTK_CONTAINER (scrolledwindow6), cookies);
  gtk_text_view_set_editable (GTK_TEXT_VIEW (cookies), FALSE);

  dialog_action_area11 = GTK_DIALOG (grab_cookie_dialog)->action_area;
  gtk_widget_show (dialog_action_area11);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area11), GTK_BUTTONBOX_END);

  close_bt = gtk_button_new_from_stock ("gtk-close");
  gtk_widget_show (close_bt);
  gtk_dialog_add_action_widget (GTK_DIALOG (grab_cookie_dialog), close_bt, GTK_RESPONSE_CLOSE);
  GTK_WIDGET_SET_FLAGS (close_bt, GTK_CAN_DEFAULT);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (grab_cookie_dialog, grab_cookie_dialog, "grab_cookie_dialog");
  GLADE_HOOKUP_OBJECT_NO_REF (grab_cookie_dialog, dialog_vbox11, "dialog_vbox11");
  GLADE_HOOKUP_OBJECT (grab_cookie_dialog, vbox15, "vbox15");
  GLADE_HOOKUP_OBJECT (grab_cookie_dialog, label61, "label61");
  GLADE_HOOKUP_OBJECT (grab_cookie_dialog, hseparator4, "hseparator4");
  GLADE_HOOKUP_OBJECT (grab_cookie_dialog, scrolledwindow6, "scrolledwindow6");
  GLADE_HOOKUP_OBJECT (grab_cookie_dialog, cookies, "cookies");
  GLADE_HOOKUP_OBJECT_NO_REF (grab_cookie_dialog, dialog_action_area11, "dialog_action_area11");
  GLADE_HOOKUP_OBJECT (grab_cookie_dialog, close_bt, "close_bt");

  return grab_cookie_dialog;
}

GtkWidget*
create_fontselectiondialog (void)
{
  GtkWidget *fontselectiondialog;
  GtkWidget *ok_button2;
  GtkWidget *cancel_button2;
  GtkWidget *apply_button1;
  GtkWidget *font_selection1;

  fontselectiondialog = gtk_font_selection_dialog_new (_("Select Font"));
  gtk_container_set_border_width (GTK_CONTAINER (fontselectiondialog), 4);
  gtk_window_set_type_hint (GTK_WINDOW (fontselectiondialog), GDK_WINDOW_TYPE_HINT_DIALOG);

  ok_button2 = GTK_FONT_SELECTION_DIALOG (fontselectiondialog)->ok_button;
  gtk_widget_show (ok_button2);
  GTK_WIDGET_SET_FLAGS (ok_button2, GTK_CAN_DEFAULT);

  cancel_button2 = GTK_FONT_SELECTION_DIALOG (fontselectiondialog)->cancel_button;
  gtk_widget_show (cancel_button2);
  GTK_WIDGET_SET_FLAGS (cancel_button2, GTK_CAN_DEFAULT);

  apply_button1 = GTK_FONT_SELECTION_DIALOG (fontselectiondialog)->apply_button;
  GTK_WIDGET_SET_FLAGS (apply_button1, GTK_CAN_DEFAULT);

  font_selection1 = GTK_FONT_SELECTION_DIALOG (fontselectiondialog)->fontsel;
  gtk_widget_show (font_selection1);
  gtk_container_set_border_width (GTK_CONTAINER (font_selection1), 4);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (fontselectiondialog, fontselectiondialog, "fontselectiondialog");
  GLADE_HOOKUP_OBJECT_NO_REF (fontselectiondialog, ok_button2, "ok_button2");
  GLADE_HOOKUP_OBJECT_NO_REF (fontselectiondialog, cancel_button2, "cancel_button2");
  GLADE_HOOKUP_OBJECT_NO_REF (fontselectiondialog, apply_button1, "apply_button1");
  GLADE_HOOKUP_OBJECT_NO_REF (fontselectiondialog, font_selection1, "font_selection1");

  return fontselectiondialog;
}

GtkWidget*
create_proxy_dialog (void)
{
  GtkWidget *proxy_dialog;
  GtkWidget *dialog_vbox12;
  GtkWidget *vbox21;
  GtkWidget *label101;
  GtkWidget *hbox37;
  GtkWidget *image16;
  GtkWidget *label100;
  GtkWidget *hseparator8;
  GtkWidget *table7;
  GtkWidget *label96;
  GtkWidget *label97;
  GtkWidget *label98;
  GtkWidget *label99;
  GtkWidget *proxy_nocache;
  GtkWidget *use_if_modified_since;
  GtkWidget *proxy_name;
  GtkObject *proxy_port_adj;
  GtkWidget *proxy_port;
  GtkWidget *proxy_auth_user;
  GtkWidget *proxy_auth_pass;
  GtkWidget *dialog_action_area12;
  GtkWidget *cancelbutton4;
  GtkWidget *okbutton4;

  proxy_dialog = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (proxy_dialog), _("Proxy or not proxy"));
  gtk_window_set_type_hint (GTK_WINDOW (proxy_dialog), GDK_WINDOW_TYPE_HINT_DIALOG);

  dialog_vbox12 = GTK_DIALOG (proxy_dialog)->vbox;
  gtk_widget_show (dialog_vbox12);

  vbox21 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox21);
  gtk_box_pack_start (GTK_BOX (dialog_vbox12), vbox21, TRUE, TRUE, 0);

  label101 = gtk_label_new (_("<b>The Charles Bronson's Advice</b>:"));
  gtk_widget_show (label101);
  gtk_box_pack_start (GTK_BOX (vbox21), label101, FALSE, FALSE, 0);
  gtk_label_set_use_markup (GTK_LABEL (label101), TRUE);

  hbox37 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox37);
  gtk_box_pack_start (GTK_BOX (vbox21), hbox37, FALSE, FALSE, 0);

  image16 = create_pixmap (proxy_dialog, "cbronson.jpg");
  gtk_widget_show (image16);
  gtk_box_pack_start (GTK_BOX (hbox37), image16, FALSE, FALSE, 0);

  label100 = gtk_label_new (_("Here you may change the proxy settings for the selected sites.\n\nNote that '<i>disable proxy caching</i>' might be useful even if you do not have filled a proxy (i.e. if your ISP uses a transparent proxy) (well I am not 100% sure of that)\n\nThe '<i>if modified since</i>' check-box is not proxy related and should always be checked.\n\nIf you don't specify any proxy, then wmcoincoin will use the content of the environment variable <tt><b>http_proxy</b></tt>\n\nIf you have any problem, you can still look at the output of 'wmcoincoin -v2', and you will see the http headers sent, and the answers of the servers or proxies."));
  gtk_widget_show (label100);
  gtk_box_pack_start (GTK_BOX (hbox37), label100, TRUE, TRUE, 5);
  gtk_label_set_use_markup (GTK_LABEL (label100), TRUE);
  gtk_label_set_line_wrap (GTK_LABEL (label100), TRUE);

  hseparator8 = gtk_hseparator_new ();
  gtk_widget_show (hseparator8);
  gtk_box_pack_start (GTK_BOX (vbox21), hseparator8, TRUE, TRUE, 0);

  table7 = gtk_table_new (3, 4, FALSE);
  gtk_widget_show (table7);
  gtk_box_pack_start (GTK_BOX (vbox21), table7, TRUE, TRUE, 0);

  label96 = gtk_label_new (_("Proxy: "));
  gtk_widget_show (label96);
  gtk_table_attach (GTK_TABLE (table7), label96, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label96), 0, 0.5);

  label97 = gtk_label_new (_("Port: "));
  gtk_widget_show (label97);
  gtk_table_attach (GTK_TABLE (table7), label97, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label97), 0, 0.5);

  label98 = gtk_label_new (_("User: "));
  gtk_widget_show (label98);
  gtk_table_attach (GTK_TABLE (table7), label98, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label98), 0, 0.5);

  label99 = gtk_label_new (_("Password: "));
  gtk_widget_show (label99);
  gtk_table_attach (GTK_TABLE (table7), label99, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label99), 0, 0.5);

  proxy_nocache = gtk_check_button_new_with_mnemonic (_("Disable proxy caching"));
  gtk_widget_show (proxy_nocache);
  gtk_table_attach (GTK_TABLE (table7), proxy_nocache, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  use_if_modified_since = gtk_check_button_new_with_mnemonic (_("Use 'if-modified-since' "));
  gtk_widget_show (use_if_modified_since);
  gtk_table_attach (GTK_TABLE (table7), use_if_modified_since, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  proxy_name = gtk_entry_new ();
  gtk_widget_show (proxy_name);
  gtk_table_attach (GTK_TABLE (table7), proxy_name, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  proxy_port_adj = gtk_adjustment_new (1, 0, 65535, 1, 10, 10);
  proxy_port = gtk_spin_button_new (GTK_ADJUSTMENT (proxy_port_adj), 1, 0);
  gtk_widget_show (proxy_port);
  gtk_table_attach (GTK_TABLE (table7), proxy_port, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  proxy_auth_user = gtk_entry_new ();
  gtk_widget_show (proxy_auth_user);
  gtk_table_attach (GTK_TABLE (table7), proxy_auth_user, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  proxy_auth_pass = gtk_entry_new ();
  gtk_widget_show (proxy_auth_pass);
  gtk_table_attach (GTK_TABLE (table7), proxy_auth_pass, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_visibility (GTK_ENTRY (proxy_auth_pass), FALSE);

  dialog_action_area12 = GTK_DIALOG (proxy_dialog)->action_area;
  gtk_widget_show (dialog_action_area12);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area12), GTK_BUTTONBOX_END);

  cancelbutton4 = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (cancelbutton4);
  gtk_dialog_add_action_widget (GTK_DIALOG (proxy_dialog), cancelbutton4, GTK_RESPONSE_CANCEL);
  GTK_WIDGET_SET_FLAGS (cancelbutton4, GTK_CAN_DEFAULT);

  okbutton4 = gtk_button_new_from_stock ("gtk-ok");
  gtk_widget_show (okbutton4);
  gtk_dialog_add_action_widget (GTK_DIALOG (proxy_dialog), okbutton4, GTK_RESPONSE_OK);
  GTK_WIDGET_SET_FLAGS (okbutton4, GTK_CAN_DEFAULT);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (proxy_dialog, proxy_dialog, "proxy_dialog");
  GLADE_HOOKUP_OBJECT_NO_REF (proxy_dialog, dialog_vbox12, "dialog_vbox12");
  GLADE_HOOKUP_OBJECT (proxy_dialog, vbox21, "vbox21");
  GLADE_HOOKUP_OBJECT (proxy_dialog, label101, "label101");
  GLADE_HOOKUP_OBJECT (proxy_dialog, hbox37, "hbox37");
  GLADE_HOOKUP_OBJECT (proxy_dialog, image16, "image16");
  GLADE_HOOKUP_OBJECT (proxy_dialog, label100, "label100");
  GLADE_HOOKUP_OBJECT (proxy_dialog, hseparator8, "hseparator8");
  GLADE_HOOKUP_OBJECT (proxy_dialog, table7, "table7");
  GLADE_HOOKUP_OBJECT (proxy_dialog, label96, "label96");
  GLADE_HOOKUP_OBJECT (proxy_dialog, label97, "label97");
  GLADE_HOOKUP_OBJECT (proxy_dialog, label98, "label98");
  GLADE_HOOKUP_OBJECT (proxy_dialog, label99, "label99");
  GLADE_HOOKUP_OBJECT (proxy_dialog, proxy_nocache, "proxy_nocache");
  GLADE_HOOKUP_OBJECT (proxy_dialog, use_if_modified_since, "use_if_modified_since");
  GLADE_HOOKUP_OBJECT (proxy_dialog, proxy_name, "proxy_name");
  GLADE_HOOKUP_OBJECT (proxy_dialog, proxy_port, "proxy_port");
  GLADE_HOOKUP_OBJECT (proxy_dialog, proxy_auth_user, "proxy_auth_user");
  GLADE_HOOKUP_OBJECT (proxy_dialog, proxy_auth_pass, "proxy_auth_pass");
  GLADE_HOOKUP_OBJECT_NO_REF (proxy_dialog, dialog_action_area12, "dialog_action_area12");
  GLADE_HOOKUP_OBJECT (proxy_dialog, cancelbutton4, "cancelbutton4");
  GLADE_HOOKUP_OBJECT (proxy_dialog, okbutton4, "okbutton4");

  return proxy_dialog;
}

